@@ -5,7 +5,7 @@
  * Also useful as an example of how to use the img code in your own programs
  */
 
-/* Copyright (C) 1994-2004,2008,2010,2011,2013 Olly Betts
+/* Copyright (C) 1994-2004,2008,2010,2011,2013,2014 Olly Betts
  * Copyright (C) 2004 John Pybus (SVG Output code)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -41,6 +41,7 @@
 #include "hash.h"
 #include "img_hosted.h"
 #include "message.h"
+#include "str.h"
 #include "useful.h"
 
 /* default values - can be overridden with --text-height and --marker-size
@@ -199,13 +200,13 @@ dxf_header(void)
 static void
 dxf_start_pass(int layer)
 {
-   layer = layer;
+   (void)layer;
 }
 
 static void
 dxf_move(const img_point *p)
 {
-   p = p; /* unused */
+   (void)p; /* unused */
 }
 
 static void
@@ -285,15 +286,15 @@ skencil_move(const img_point *p)
 static void
 skencil_line(const img_point *p1, const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
-   p1 = p1; /* unused */
+   (void)fSurface; /* unused */
+   (void)p1; /* unused */
    fprintf(fh, "bs(%.3f,%.3f,%.3f)\n", p->x * factor, p->y * factor, 0.0);
 }
 
 static void
 skencil_label(const img_point *p, const char *s, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "fp((0,0,0))\n");
    fprintf(fh, "le()\n");
    fprintf(fh, "Fn('Times-Roman')\n");
@@ -310,7 +311,7 @@ skencil_label(const img_point *p, const char *s, bool fSurface)
 static void
 skencil_cross(const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "b()\n");
    fprintf(fh, "bs(%.3f,%.3f,%.3f)\n",
 	   p->x * factor - marker_size, p->y * factor - marker_size, 0.0);
@@ -344,7 +345,7 @@ typedef struct point {
 static point **htab;
 
 static void
-set_name(const img_point *p, const char *s)
+set_name_(const img_point *p, const char *s, int copy)
 {
    int hash;
    point *pt;
@@ -361,17 +362,31 @@ set_name(const img_point *p, const char *s)
       if (pt->p.x == p->x && pt->p.y == p->y && pt->p.z == p->z) {
 	 /* already got name for these coordinates */
 	 /* FIXME: what about multiple names for the same station? */
+	 if (!copy)
+	    osfree((char*)s);
 	 return;
       }
    }
 
    pt = osnew(point);
-   pt->label = osstrdup(s);
+   if (copy)
+      s = osstrdup(s);
+   pt->label = s;
    pt->p = *p;
    pt->next = htab[hash];
    htab[hash] = pt;
+}
 
-   return;
+static void
+set_name(const img_point *p, const char *s)
+{
+   set_name_(p, s, 0);
+}
+
+static void
+set_name_copy(const img_point *p, const char *s)
+{
+   set_name_(p, s, 1);
 }
 
 static const char *
@@ -451,8 +466,8 @@ svg_move(const img_point *p)
 static void
 svg_line(const img_point *p1, const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
-   p1 = p1; /* unused */
+   (void)fSurface; /* unused */
+   (void)p1; /* unused */
    fprintf(fh, "L%.3f %.3f", p->x * factor, p->y * -factor);
    to_close = 1;
 }
@@ -460,18 +475,18 @@ svg_line(const img_point *p1, const img_point *p, bool fSurface)
 static void
 svg_label(const img_point *p, const char *s, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "<text transform=\"translate(%.3f %.3f)\">",
            p->x * factor, p->y * -factor);
    fputs(s, fh);
    fputs("</text>\n", fh);
-   set_name(p, s);
+   set_name_copy(p, s);
 }
 
 static void
 svg_cross(const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "<circle id=\"%s\" cx=\"%.3f\" cy=\"%.3f\" r=\"%.3f\"/>\n",
 	   find_name(p), p->x * factor, p->y * -factor, marker_size * SQRT_2);
    fprintf(fh, "<path d=\"M%.3f %.3fL%.3f %.3fM%.3f %.3fL%.3f %.3f\"/>\n",
@@ -512,7 +527,7 @@ plt_header(void)
 static void
 plt_start_pass(int layer)
 {
-   layer = layer;
+   (void)layer;
 }
 
 static void
@@ -528,8 +543,8 @@ plt_move(const img_point *p)
 static void
 plt_line(const img_point *p1, const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
-   p1 = p1; /* unused */
+   (void)fSurface; /* unused */
+   (void)p1; /* unused */
    /* Survex is E, N, Alt - PLT file is N, E, Alt */
    fprintf(fh, "D %.3f %.3f %.3f ",
 	   p->y / METRES_PER_FOOT, p->x / METRES_PER_FOOT, p->z / METRES_PER_FOOT);
@@ -540,20 +555,37 @@ plt_line(const img_point *p1, const img_point *p, bool fSurface)
 static void
 plt_label(const img_point *p, const char *s, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
-   /* FIXME: also ctrl characters - ought to remap them, not give up */
-   if (strchr(s, ' ')) {
-      fprintf(stderr, "PLT format can't cope with spaces in station names\n");
-      exit(1);
+   const char * q;
+   char * escaped = NULL;
+   int elen;
+   (void)fSurface; /* unused */
+   /* PLT format can't handle spaces or control characters, so escape them
+    * like in URLs (an arbitrary choice of escaping, but at least a familiar
+    * one and % isn't likely to occur in station names).
+    */
+   for (q = s; *q; ++q) {
+      unsigned char ch = *q;
+      if (ch <= ' ' || ch == '%') {
+	 s_catlen(&escaped, &elen, s, q - s);
+	 s_catchar(&escaped, &elen, '%');
+	 s_catchar(&escaped, &elen, "0123456789abcdef"[ch >> 4]);
+	 s_catchar(&escaped, &elen, "0123456789abcdef"[ch & 0x0f]);
+	 s = q + 1;
+      }
    }
-   set_name(p, s);
+   if (escaped) {
+      s_catlen(&escaped, &elen, s, q - s);
+      set_name(p, escaped);
+      return;
+   }
+   set_name_copy(p, s);
 }
 
 static void
 plt_cross(const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
-   p = p; /* unused */
+   (void)fSurface; /* unused */
+   (void)p; /* unused */
 }
 
 static void
