@@ -1,6 +1,6 @@
 /* cavern.c
  * SURVEX Cave surveying software: data reduction main and related functions
- * Copyright (C) 1991-2003,2004,2005,2010,2011 Olly Betts
+ * Copyright (C) 1991-2003,2004,2005,2010,2011,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 #include "message.h"
 #include "filename.h"
 #include "filelist.h"
-#include "img.h"
+#include "img_hosted.h"
 #include "listpos.h"
 #include "netbits.h"
 #include "netskel.h"
@@ -57,6 +57,7 @@
 node *stnlist = NULL;
 settings *pcs;
 prefix *root;
+prefix *anon_list = NULL;
 long cLegs, cStns;
 long cComponents;
 bool fExportUsed = fFalse;
@@ -334,7 +335,7 @@ main(int argc, char **argv)
    /* close .3d file */
    if (!img_close(pimg)) {
       char *fnm = add_ext(fnm_output_base, EXT_SVX_3D);
-      fatalerror(img_error(), fnm);
+      fatalerror(img_error2msg(img_error()), fnm);
    }
    if (fhErrStat) safe_fclose(fhErrStat);
 
@@ -390,8 +391,9 @@ main(int argc, char **argv)
 static void
 do_range(int d, int msgno)
 {
-   // sprint_prefix uses a single buffer, so to report two stations in one
-   // message we need to make a temporary copy of the string for one of them.
+   /* sprint_prefix uses a single buffer, so to report two stations in one
+    * message we need to make a temporary copy of the string for one of them.
+    */
    char * pfx_hi = osstrdup(sprint_prefix(pfxHi[d]));
    char * pfx_lo = sprint_prefix(pfxLo[d]);
    printf(msg(msgno), max[d] - min[d], pfx_hi, max[d], pfx_lo, min[d]);
