@@ -1,6 +1,6 @@
 /* cavern.h
  * SURVEX Cave surveying software - header file
- * Copyright (C) 1991-2003,2005,2006,2010 Olly Betts
+ * Copyright (C) 1991-2003,2005,2006,2010,2013 Olly Betts
  * Copyright (C) 2004 Simeon Warner
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 #include <math.h>
 #include <float.h>
 
-#include "img.h"
+#include "img_hosted.h"
 #include "useful.h"
 
 /* Set EXPLICIT_FIXED_FLAG to 1 to force an explicit fixed flag to be used
@@ -109,16 +109,26 @@ typedef enum {
 /* don't reorder these values!  They need to match with img.h too */
 typedef enum {
    FLAGS_NOT = -2, FLAGS_UNKNOWN = -1, FLAGS_SURFACE, FLAGS_DUPLICATE,
-   FLAGS_SPLAY
+   FLAGS_SPLAY,
 #if 0
-   ,
    /* underground, but through rock (e.g. radiolocation).  Want to hide from
     * plots by default (so not cave) but don't want to include in surface
     * triangulation nets (so not surface) */
-   FLAGS_SKELETAL /* FIXME */
+   FLAGS_SKELETAL, /* FIXME */
 #endif
+   /* Don't need to match img.h: */
+   FLAGS_ANON_ONE_END,
+   FLAGS_IMPLICIT_SPLAY,
+   FLAGS_STYLE_BIT0, FLAGS_STYLE_BIT1, FLAGS_STYLE_BIT2
 } flags;
 
+/* flags are currently stored in an unsigned char */
+typedef int compiletimeassert_flags0[FLAGS_STYLE_BIT2 <= 7 ? 1 : -1];
+
+/* Mask to AND with to get bits to pass to img library. */
+#define FLAGS_MASK \
+    (BIT(FLAGS_SURFACE) | BIT(FLAGS_DUPLICATE) | BIT(FLAGS_SPLAY))
+
 typedef int compiletimeassert_flags1[BIT(FLAGS_SURFACE) == img_FLAG_SURFACE ? 1 : -1];
 typedef int compiletimeassert_flags2[BIT(FLAGS_DUPLICATE) == img_FLAG_DUPLICATE ? 1 : -1];
 typedef int compiletimeassert_flags3[BIT(FLAGS_SPLAY) == img_FLAG_SPLAY ? 1 : -1];
@@ -126,20 +136,24 @@ typedef int compiletimeassert_flags3[BIT(FLAGS_SPLAY) == img_FLAG_SPLAY ? 1 : -1
 typedef enum {
    /* Don't reorder these values!  They need to match with img.h too. */
    SFLAGS_SURFACE = 0, SFLAGS_UNDERGROUND, SFLAGS_ENTRANCE, SFLAGS_EXPORTED,
-   SFLAGS_FIXED,
+   SFLAGS_FIXED, SFLAGS_ANON, SFLAGS_WALL,
    /* These values don't need to match img.h, but mustn't clash. */
+   SFLAGS_USED = 11,
    SFLAGS_SOLVED = 12, SFLAGS_SUSPECTTYPO = 13, SFLAGS_SURVEY = 14, SFLAGS_PREFIX_ENTERED = 15
 } sflags;
 
 /* Mask to AND with to get bits to pass to img library. */
 #define SFLAGS_MASK (BIT(SFLAGS_SURFACE) | BIT(SFLAGS_UNDERGROUND) |\
-	BIT(SFLAGS_ENTRANCE) | BIT(SFLAGS_EXPORTED) | BIT(SFLAGS_FIXED))
+	BIT(SFLAGS_ENTRANCE) | BIT(SFLAGS_EXPORTED) | BIT(SFLAGS_FIXED) |\
+	BIT(SFLAGS_ANON) | BIT(SFLAGS_WALL))
 
 typedef int compiletimeassert_sflags1[BIT(SFLAGS_SURFACE) == img_SFLAG_SURFACE ? 1 : -1];
 typedef int compiletimeassert_sflags2[BIT(SFLAGS_UNDERGROUND) == img_SFLAG_UNDERGROUND ? 1 : -1];
 typedef int compiletimeassert_sflags3[BIT(SFLAGS_ENTRANCE) == img_SFLAG_ENTRANCE ? 1 : -1];
 typedef int compiletimeassert_sflags4[BIT(SFLAGS_EXPORTED) == img_SFLAG_EXPORTED ? 1 : -1];
 typedef int compiletimeassert_sflags5[BIT(SFLAGS_FIXED) == img_SFLAG_FIXED ? 1 : -1];
+typedef int compiletimeassert_sflags6[BIT(SFLAGS_ANON) == img_SFLAG_ANON ? 1 : -1];
+typedef int compiletimeassert_sflags7[BIT(SFLAGS_WALL) == img_SFLAG_WALL ? 1 : -1];
 
 /* enumeration of field types */
 typedef enum {
@@ -276,16 +290,23 @@ typedef struct Inst {
 #define STYLE_DIVING     1
 #define STYLE_CARTESIAN  2
 #define STYLE_CYLPOLAR   3
-#define STYLE_PASSAGE    4
-#define STYLE_NOSURVEY   5
+#define STYLE_NOSURVEY   4
+#define STYLE_PASSAGE    5
 #define STYLE_IGNORE     6
 
+typedef int compiletimeassert_style1[STYLE_NORMAL == img_STYLE_NORMAL ? 1 : -1];
+typedef int compiletimeassert_style2[STYLE_DIVING == img_STYLE_DIVING ? 1 : -1];
+typedef int compiletimeassert_style3[STYLE_CARTESIAN == img_STYLE_CARTESIAN ? 1 : -1];
+typedef int compiletimeassert_style4[STYLE_CYLPOLAR == img_STYLE_CYLPOLAR ? 1 : -1];
+typedef int compiletimeassert_style5[STYLE_NOSURVEY == img_STYLE_NOSURVEY ? 1 : -1];
+
 /* various settings preserved by *BEGIN and *END */
 typedef struct Settings {
    struct Settings *next;
    unsigned int Truncate;
    bool f_clino_percent;
    bool f_backclino_percent;
+   bool dash_for_anon_wall_station;
    unsigned char infer;
    enum {OFF, LOWER, UPPER} Case;
    int style;
@@ -305,6 +326,7 @@ typedef struct Settings {
 /* global variables */
 extern settings *pcs;
 extern prefix *root;
+extern prefix *anon_list;
 extern node *stnlist;
 extern unsigned long optimize;
 
