@@ -2,7 +2,7 @@
  * Export to CAD-like formats (DXF, Skencil, SVG, EPS) and also Compass PLT.
  */
 
-/* Copyright (C) 1994-2004,2005,2006,2008,2010,2011,2012,2013 Olly Betts
+/* Copyright (C) 1994-2004,2005,2006,2008,2010,2011,2012,2013,2014 Olly Betts
  * Copyright (C) 2004 John Pybus (SVG Output code)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -61,6 +61,27 @@
 
 #define SQRT_2		1.41421356237309504880168872420969
 
+static void
+html_escape(FILE *fh, const char *s)
+{
+    while (*s) {
+	switch (*s) {
+	    case '<':
+		fputs("&lt;", fh);
+		break;
+	    case '>':
+		fputs("&gt;", fh);
+		break;
+	    case '&':
+		fputs("&amp;", fh);
+		break;
+	    default:
+		PUTC(*s, fh);
+	}
+	++s;
+    }
+}
+
 static const char *layer_name(int mask) {
     switch (mask) {
 	case LEGS: case LEGS|SURF:
@@ -109,7 +130,7 @@ class DXF : public ExportFilter {
     DXF() : to_close(0) { pending[0] = '\0'; }
     const int * passes() const;
     bool fopen(const char *fnm_out);
-    void header(const char *);
+    void header(const char *, const char *, time_t);
     void line(const img_point *, const img_point *, bool, bool);
     void label(const img_point *, const char *, bool, int);
     void cross(const img_point *, bool);
@@ -138,7 +159,7 @@ DXF::fopen(const char *fnm_out)
 }
 
 void
-DXF::header(const char *)
+DXF::header(const char *, const char *, time_t)
 {
    fprintf(fh, "0\nSECTION\n"
 	       "2\nHEADER\n");
@@ -259,7 +280,7 @@ DXF::header(const char *)
 void
 DXF::line(const img_point *p1, const img_point *p, bool fSurface, bool fPendingMove)
 {
-   fPendingMove = fPendingMove; /* unused */
+   (void)fPendingMove; /* unused */
    fprintf(fh, "0\nLINE\n");
    fprintf(fh, fSurface ? "8\nSurface\n" : "8\nCentreLine\n"); /* Layer */
    fprintf(fh, "10\n%6.2f\n", p1->x);
@@ -372,7 +393,7 @@ class Skencil : public ExportFilter {
   public:
     Skencil() { }
     const int * passes() const;
-    void header(const char *);
+    void header(const char *, const char *, time_t);
     void start_pass(int layer);
     void line(const img_point *, const img_point *, bool, bool);
     void label(const img_point *, const char *, bool, int);
@@ -388,7 +409,7 @@ Skencil::passes() const
 }
 
 void
-Skencil::header(const char *)
+Skencil::header(const char *, const char *, time_t)
 {
    fprintf(fh, "##Sketch 1 2\n"); /* File format version */
    fprintf(fh, "document()\n");
@@ -405,7 +426,7 @@ Skencil::start_pass(int layer)
 void
 Skencil::line(const img_point *p1, const img_point *p, bool fSurface, bool fPendingMove)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    if (fPendingMove) {
        fprintf(fh, "b()\n");
        fprintf(fh, "bs(%.3f,%.3f,%.3f)\n", p1->x * factor, p1->y * factor, 0.0);
@@ -416,7 +437,7 @@ Skencil::line(const img_point *p1, const img_point *p, bool fSurface, bool fPend
 void
 Skencil::label(const img_point *p, const char *s, bool fSurface, int)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "fp((0,0,0))\n");
    fprintf(fh, "le()\n");
    fprintf(fh, "Fn('Times-Roman')\n");
@@ -433,7 +454,7 @@ Skencil::label(const img_point *p, const char *s, bool fSurface, int)
 void
 Skencil::cross(const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "b()\n");
    fprintf(fh, "bs(%.3f,%.3f,%.3f)\n",
 	   p->x * factor - marker_size, p->y * factor - marker_size, 0.0);
@@ -527,7 +548,7 @@ class SVG : public ExportFilter {
   public:
     SVG() : to_close(NULL), close_g(false) { pending[0] = '\0'; }
     const int * passes() const;
-    void header(const char *);
+    void header(const char *, const char *, time_t);
     void start_pass(int layer);
     void line(const img_point *, const img_point *, bool, bool);
     void label(const img_point *, const char *, bool, int);
@@ -549,7 +570,7 @@ SVG::passes() const
 }
 
 void
-SVG::header(const char *)
+SVG::header(const char * title, const char *, time_t)
 {
    size_t i;
    htab = (point **)osmalloc(HTAB_SIZE * ossizeof(point *));
@@ -564,6 +585,11 @@ SVG::header(const char *)
 	       "width=\"%.3f%s\" height=\"%.3f%s\"\n"
 	       "viewBox=\"0 0 %0.3f %0.3f\">\n",
 	   width, unit, height, unit, width, height);
+   if (title && title[0]) {
+       fputs("<title>", fh);
+       html_escape(fh, title);
+       fputs("</title>\n", fh);
+   }
    fprintf(fh, "<g transform=\"translate(%.3f %.3f)\">\n",
 	   SVG_MARGIN - min_x * factor, SVG_MARGIN + max_y * factor);
    to_close = NULL;
@@ -601,7 +627,7 @@ SVG::start_pass(int layer)
 void
 SVG::line(const img_point *p1, const img_point *p, bool fSurface, bool fPendingMove)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    if (fPendingMove) {
        if (to_close) {
 	   fputs(to_close, fh);
@@ -615,10 +641,10 @@ SVG::line(const img_point *p1, const img_point *p, bool fSurface, bool fPendingM
 void
 SVG::label(const img_point *p, const char *s, bool fSurface, int)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "<text transform=\"translate(%.3f %.3f)\">",
 	   p->x * factor, p->y * -factor);
-   fputs(s, fh);
+   html_escape(fh, s);
    fputs("</text>\n", fh);
    set_name(p, s);
 }
@@ -626,7 +652,7 @@ SVG::label(const img_point *p, const char *s, bool fSurface, int)
 void
 SVG::cross(const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "<circle id=\"%s\" cx=\"%.3f\" cy=\"%.3f\" r=\"%.3f\"/>\n",
 	   find_name(p), p->x * factor, p->y * -factor, marker_size * SQRT_2);
    fprintf(fh, "<path d=\"M%.3f %.3fL%.3f %.3fM%.3f %.3fL%.3f %.3f\"/>\n",
@@ -708,7 +734,7 @@ class PLT : public ExportFilter {
   public:
     PLT() { }
     const int * passes() const;
-    void header(const char *);
+    void header(const char *, const char *, time_t);
     void line(const img_point *, const img_point *, bool, bool);
     void label(const img_point *, const char *, bool, int);
     void footer();
@@ -722,7 +748,7 @@ PLT::passes() const
 }
 
 void
-PLT::header(const char *title)
+PLT::header(const char *title, const char *, time_t)
 {
    size_t i;
    htab = (point **)osmalloc(HTAB_SIZE * ossizeof(point *));
@@ -739,7 +765,7 @@ PLT::header(const char *title)
 void
 PLT::line(const img_point *p1, const img_point *p, bool fSurface, bool fPendingMove)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    if (fPendingMove) {
        /* Survex is E, N, Alt - PLT file is N, E, Alt */
        fprintf(fh, "M %.3f %.3f %.3f ",
@@ -784,7 +810,7 @@ PLT::find_name_plt(const img_point *p)
 void
 PLT::label(const img_point *p, const char *s, bool fSurface, int)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    set_name(p, s);
 }
 
@@ -803,7 +829,7 @@ PLT::footer(void)
 class EPS : public ExportFilter {
   public:
     EPS() { }
-    void header(const char *);
+    void header(const char *, const char *, time_t);
     void line(const img_point *, const img_point *, bool, bool);
     void label(const img_point *, const char *, bool, int);
     void cross(const img_point *, bool);
@@ -811,14 +837,15 @@ class EPS : public ExportFilter {
 };
 
 void
-EPS::header(const char *title)
+EPS::header(const char *title, const char *, time_t)
 {
    const char * fontname_labels = "helvetica"; // FIXME
    int fontsize_labels = 10; // FIXME
    fputs("%!PS-Adobe-2.0 EPSF-1.2\n", fh);
    fputs("%%Creator: Survex "VERSION" EPS Output Filter\n", fh);
 
-   if (title && title[0]) fprintf(fh, "%%%%Title: %s\n", title);
+   if (title && title[0])
+       fprintf(fh, "%%%%Title: %s\n", title);
 
    char buf[64];
    time_t now = time(NULL);
@@ -1047,7 +1074,7 @@ EPS::header(const char *title)
 void
 EPS::line(const img_point *p1, const img_point *p, bool fSurface, bool fPendingMove)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    if (fPendingMove) {
        fprintf(fh, "%.2f %.2f M\n", p1->x, p1->y);
    }
@@ -1077,7 +1104,7 @@ EPS::label(const img_point *p, const char *s, bool /*fSurface*/, int)
 void
 EPS::cross(const img_point *p, bool fSurface)
 {
-   fSurface = fSurface; /* unused */
+   (void)fSurface; /* unused */
    fprintf(fh, "%.2f %.2f X\n", p->x, p->y);
 }
 
@@ -1091,7 +1118,9 @@ EPS::footer(void)
 }
 
 bool
-Export(const wxString &fnm_out, const wxString &title, const MainFrm * mainfrm,
+Export(const wxString &fnm_out, const wxString &title,
+       const wxString &datestamp, time_t datestamp_numeric,
+       const MainFrm * mainfrm,
        double pan, double tilt, int show_mask, export_format format,
        const char * input_projection,
        double grid_, double text_height_, double marker_size_)
@@ -1252,7 +1281,7 @@ Export(const wxString &fnm_out, const wxString &title, const MainFrm * mainfrm,
    max_z += z_offset;
 
    /* Header */
-   filt->header(title.mb_str());
+   filt->header(title.mb_str(), datestamp.mb_str(), datestamp_numeric);
 
    p1.x = p1.y = p1.z = 0; /* avoid compiler warning */
 
