@@ -4,7 +4,7 @@
 //  Core drawing code for Aven.
 //
 //  Copyright (C) 2000-2003,2005,2006 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2007,2010,2011,2012 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2007,2010,2011,2012,2014 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -142,6 +142,7 @@ GfxCore::GfxCore(MainFrm* parent, wxWindow* parent_win, GUIControl* control) :
     m_BoundingBox(false),
     m_Degrees(false),
     m_Metric(false),
+    m_Percent(false),
     m_HitTestGridValid(false),
     m_here_is_temporary(false),
     presentation_mode(0),
@@ -154,13 +155,13 @@ GfxCore::GfxCore(MainFrm* parent, wxWindow* parent_win, GUIControl* control) :
     AddPoly = &GfxCore::AddPolylineDepth;
     wxConfigBase::Get()->Read(wxT("metric"), &m_Metric, true);
     wxConfigBase::Get()->Read(wxT("degrees"), &m_Degrees, true);
+    wxConfigBase::Get()->Read(wxT("percent"), &m_Percent, false);
     m_here.Invalidate();
     m_there.Invalidate();
 
     // Initialise grid for hit testing.
     m_PointGrid = new list<LabelInfo*>[HITTEST_SIZE * HITTEST_SIZE];
 
-    m_Pens = new GLAPen[NUM_COLOUR_BANDS + 1];
     for (int pen = 0; pen < NUM_COLOUR_BANDS + 1; ++pen) {
 	m_Pens[pen].SetColour(REDS[pen] / 255.0,
 			      GREENS[pen] / 255.0,
@@ -172,7 +173,6 @@ GfxCore::~GfxCore()
 {
     TryToFreeArrays();
 
-    delete[] m_Pens;
     delete[] m_PointGrid;
 }
 
@@ -639,12 +639,16 @@ void GfxCore::Draw2dIndicators()
     if (m_Compass && !m_Parent->IsExtendedElevation()) {
 	wxString str;
 	int value;
+	int brg_unit;
 	if (m_Degrees) {
 	    value = int(m_PanAngle);
+	    brg_unit = /*°*/344;
 	} else {
 	    value = int(m_PanAngle * 200.0 / 180.0);
+	    brg_unit = /*ᵍ*/76;
 	}
 	str.Printf(wxT("%03d"), value);
+	str += wmsg(brg_unit);
 	DrawIndicatorText(comp_centre_x - triple_zero_width / 2, y_off, str);
 
 	str = wmsg(/*Facing*/203);
@@ -657,7 +661,28 @@ void GfxCore::Draw2dIndicators()
 	int angle;
 	wxString str;
 	int width;
-	if (m_Degrees) {
+	int unit;
+	if (m_Percent) {
+	    static int zero_width = 0;
+	    if (!zero_width) {
+		GetTextExtent(wxT("0"), &zero_width, NULL);
+	    }
+	    width = zero_width;
+	    if (m_TiltAngle > 89.99) {
+		angle = 1000000;
+	    } else if (m_TiltAngle < -89.99) {
+		angle = -1000000;
+	    } else {
+		angle = int(100 * tan(rad(m_TiltAngle)));
+	    }
+	    if (angle > 99999 || angle < -99999) {
+		str = angle > 0 ? wxT("+") : wxT("-");
+		str += wmsg(/*∞*/431);
+	    } else {
+		str = angle ? wxString::Format(wxT("%+03d"), angle) : wxT("0");
+	    }
+	    unit = /*%*/96;
+	} else if (m_Degrees) {
 	    static int zero_zero_width = 0;
 	    if (!zero_zero_width) {
 		GetTextExtent(wxT("00"), &zero_zero_width, NULL);
@@ -665,34 +690,47 @@ void GfxCore::Draw2dIndicators()
 	    width = zero_zero_width;
 	    angle = int(m_TiltAngle);
 	    str = angle ? wxString::Format(wxT("%+03d"), angle) : wxT("00");
+	    unit = /*°*/344;
 	} else {
 	    width = triple_zero_width;
 	    angle = int(m_TiltAngle * 200.0 / 180.0);
 	    str = angle ? wxString::Format(wxT("%+04d"), angle) : wxT("000");
+	    unit = /*ᵍ*/76;
 	}
 
-	// Adjust horizontal position so the left of the first digit is
-	// always in the same place.
 	int sign_offset = 0;
-	if (angle < 0) {
+	if (unit == /*%*/96) {
+	    // Right align % since the width changes so much.
+	    GetTextExtent(str, &sign_offset, NULL);
+	    sign_offset -= width;
+	} else if (angle < 0) {
+	    // Adjust horizontal position so the left of the first digit is
+	    // always in the same place.
 	    static int minus_width = 0;
 	    if (!minus_width) {
 		GetTextExtent(wxT("-"), &minus_width, NULL);
 	    }
-	    sign_offset = minus_width + 1;
+	    sign_offset = minus_width;
 	} else if (angle > 0) {
+	    // Adjust horizontal position so the left of the first digit is
+	    // always in the same place.
 	    static int plus_width = 0;
 	    if (!plus_width) {
 		GetTextExtent(wxT("+"), &plus_width, NULL);
 	    }
-	    sign_offset = plus_width + 1;
+	    sign_offset = plus_width;
 	}
+
+	str += wmsg(unit);
 	DrawIndicatorText(elev_centre_x - sign_offset - width / 2, y_off, str);
 
 	str = wmsg(/*Elevation*/118);
-	int w;
-	GetTextExtent(str, &w, NULL);
-	DrawIndicatorText(elev_centre_x - w / 2, y_off + height, str);
+	static int elevation_width = 0;
+	if (!elevation_width) {
+	    GetTextExtent(str, &elevation_width, NULL);
+	}
+	int x = elev_centre_x - elevation_width / 2;
+	DrawIndicatorText(x, y_off + height, str);
     }
 }
 
@@ -901,7 +939,7 @@ void GfxCore::DrawDepthKey()
 	key_legends[band].Printf(wxT("%.*f"), sf, z);
     }
 
-    DrawColourKey(num_bands, wxString(), m_Metric ? wxT("m") : wxT("ft"));
+    DrawColourKey(num_bands, wxString(), wmsg(m_Metric ? /*m*/424: /*ft*/428));
 }
 
 void GfxCore::DrawDateKey()
@@ -1013,34 +1051,41 @@ void GfxCore::DrawScaleBar()
 
     // Add labels.
     wxString str;
+    int units;
     if (m_Metric) {
-	if (size_snap >= 1e3) {
-	    str.Printf(wxT("%.fkm"), size_snap * 1e-3);
+	Double km = size_snap * 1e-3;
+	if (km >= 1.0) {
+	    size_snap = km;
+	    units = /*km*/423;
 	} else if (size_snap >= 1.0) {
-	    str.Printf(wxT("%.fm"), size_snap);
+	    units = /*m*/424;
 	} else {
-	    int sf = -(int)floor(log10(size_snap));
-	    str.Printf(wxT("%.*fm"), sf, size_snap);
+	    size_snap *= 1e2;
+	    units = /*cm*/425;
 	}
     } else {
 	size_snap /= METRES_PER_FOOT;
 	Double miles = size_snap / 5280.0;
-	if (miles >= 2.0) {
-	    str.Printf(wxT("%.f miles"), miles);
-	} else if (miles >= 1.0) {
-	    str.Printf(wxT("%.f mile"), miles);
-	} else if (size_snap >= 1.0) {
-	    str.Printf(wxT("%.fft"), size_snap);
-	} else {
-	    Double inches = size_snap * 12;
-	    if (inches >= 1.0) {
-		str.Printf(wxT("%.fin"), inches);
+	if (miles >= 1.0) {
+	    size_snap = miles;
+	    if (size_snap >= 2.0) {
+		units = /* miles*/426;
 	    } else {
-		int sf = -(int)floor(log10(inches));
-		str.Printf(wxT("%.*fin"), sf, inches);
+		units = /* mile*/427;
 	    }
+	} else if (size_snap >= 1.0) {
+	    units = /*ft*/428;
+	} else {
+	    size_snap *= 12.0;
+	    units = /*in*/429;
 	}
     }
+    if (size_snap >= 1.0) {
+	str.Printf(wxT("%.f%s"), size_snap, wmsg(units).c_str());
+    } else {
+	int sf = -(int)floor(log10(size_snap));
+	str.Printf(wxT("%.*f%s"), sf, size_snap, wmsg(units).c_str());
+    }
 
     int text_width, text_height;
     GetTextExtent(str, &text_width, &text_height);
@@ -1354,6 +1399,15 @@ static const int HIGHLIGHTED_PT_SIZE = 2; // FIXME: tie in to blob and ring size
 #define MARGIN (HIGHLIGHTED_PT_SIZE * 2 + 1)
 void GfxCore::RefreshLine(const Point &a, const Point &b, const Point &c)
 {
+#ifdef __WXMSW__
+    (void)a;
+    (void)b;
+    (void)c;
+    // FIXME: We get odd redraw artifacts if we just update the line, and
+    // redrawing the whole scene doesn't actually seem to be measurably
+    // slower.  That may not be true with software rendering though...
+    ForceRefresh();
+#else
     // Best of all might be to copy the window contents before we draw the
     // line, then replace each time we redraw.
 
@@ -1367,10 +1421,10 @@ void GfxCore::RefreshLine(const Point &a, const Point &b, const Point &c)
 	} else {
 	    int x = int(X);
 	    int y = GetYSize() - 1 - int(Y);
-	    l = x - MARGIN;
-	    r = x + MARGIN;
-	    u = y + MARGIN;
-	    d = y - MARGIN;
+	    l = x;
+	    r = x;
+	    u = y;
+	    d = y;
 	}
     }
     if (b.IsValid()) {
@@ -1379,10 +1433,10 @@ void GfxCore::RefreshLine(const Point &a, const Point &b, const Point &c)
 	} else {
 	    int x = int(X);
 	    int y = GetYSize() - 1 - int(Y);
-	    l = min(l, x - MARGIN);
-	    r = max(r, x + MARGIN);
-	    u = max(u, y + MARGIN);
-	    d = min(d, y - MARGIN);
+	    l = min(l, x);
+	    r = max(r, x);
+	    u = max(u, y);
+	    d = min(d, y);
 	}
     }
     if (c.IsValid()) {
@@ -1391,13 +1445,18 @@ void GfxCore::RefreshLine(const Point &a, const Point &b, const Point &c)
 	} else {
 	    int x = int(X);
 	    int y = GetYSize() - 1 - int(Y);
-	    l = min(l, x - MARGIN);
-	    r = max(r, x + MARGIN);
-	    u = max(u, y + MARGIN);
-	    d = min(d, y - MARGIN);
+	    l = min(l, x);
+	    r = max(r, x);
+	    u = max(u, y);
+	    d = min(d, y);
 	}
     }
+    l -= MARGIN;
+    r += MARGIN;
+    u += MARGIN;
+    d -= MARGIN;
     RefreshRect(wxRect(l, d, r - l, u - d), false);
+#endif
 }
 
 void GfxCore::SetHere()
@@ -2245,7 +2304,6 @@ int GfxCore::GetDepthColour(Double z) const
     // less than GetDepthMin() here, and it can certainly be true for passage
     // tubes, so just clamp the value to 0.
     if (z <= 0) return 0;
-    assert(z_ext > 0.0);
     // We seem to get rounding differences causing z to sometimes exceed z_ext
     // by a small amount here (see: http://trac.survex.com/ticket/26) and it
     // can certainly be true for passage tubes, so just clamp the value.
@@ -2876,10 +2934,11 @@ bool GfxCore::ExportMovie(const wxString & fnm)
 
 void
 GfxCore::OnPrint(const wxString &filename, const wxString &title,
-		 const wxString &datestamp)
+		 const wxString &datestamp, time_t datestamp_numeric)
 {
     svxPrintDlg * p;
-    p = new svxPrintDlg(m_Parent, filename, title, datestamp,
+    p = new svxPrintDlg(m_Parent, filename, title,
+			datestamp, datestamp_numeric,
 			m_PanAngle, m_TiltAngle,
 			m_Names, m_Crosses, m_Legs, m_Surface, m_Tubes,
 			m_Entrances, m_FixedPts, m_ExportedPts,
@@ -2888,7 +2947,8 @@ GfxCore::OnPrint(const wxString &filename, const wxString &title,
 }
 
 void
-GfxCore::OnExport(const wxString &filename, const wxString &title)
+GfxCore::OnExport(const wxString &filename, const wxString &title,
+		  const wxString &datestamp, time_t datestamp_numeric)
 {
     // Fill in "right_bearing" for each cross-section.
     list<vector<XSect> >::iterator trav = m_Parent->tubes_begin();
@@ -2899,7 +2959,8 @@ GfxCore::OnExport(const wxString &filename, const wxString &title)
     }
 
     svxPrintDlg * p;
-    p = new svxPrintDlg(m_Parent, filename, title, wxString(),
+    p = new svxPrintDlg(m_Parent, filename, title,
+			datestamp, datestamp_numeric,
 			m_PanAngle, m_TiltAngle,
 			m_Names, m_Crosses, m_Legs, m_Surface, m_Tubes,
 			m_Entrances, m_FixedPts, m_ExportedPts,
@@ -3019,6 +3080,7 @@ bool GfxCore::HandleRClick(wxPoint point)
 	menu.AppendSeparator();
 	menu.AppendCheckItem(menu_IND_CLINO, wmsg(/*&Hide Clino*/384));
 	menu.AppendCheckItem(menu_CTL_DEGREES, wmsg(/*&Degrees*/343));
+	menu.AppendCheckItem(menu_CTL_PERCENT, wmsg(/*&Percent*/430));
 	menu.Connect(wxEVT_COMMAND_MENU_SELECTED, (wxObjectEventFunction)&wxEvtHandler::ProcessEvent, NULL, m_Parent->GetEventHandler());
 	PopupMenu(&menu);
 	return true;
