@@ -4,7 +4,7 @@
 //  Core drawing code for Aven.
 //
 //  Copyright (C) 2000-2001,2002,2005 Mark R. Shinwell.
-//  Copyright (C) 2001-2004,2005,2006,2007,2010,2011,2012,2013 Olly Betts
+//  Copyright (C) 2001-2004,2005,2006,2007,2010,2011,2012,2013,2014 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 #define gfxcore_h
 
 #include <float.h>
+#include <time.h>
 
 #include "img_hosted.h"
 
@@ -178,6 +179,7 @@ private:
 
     bool m_Degrees;
     bool m_Metric;
+    bool m_Percent;
 
     list<LabelInfo*> *m_PointGrid;
     bool m_HitTestGridValid;
@@ -188,7 +190,7 @@ private:
     wxStopWatch timer;
     long drawtime;
 
-    GLAPen * m_Pens;
+    GLAPen m_Pens[NUM_COLOUR_BANDS + 1];
 
 #define PLAYING 1
     int presentation_mode; // for now, 0 => off, PLAYING => continuous play
@@ -262,12 +264,12 @@ private:
 
     void ToggleFlag(bool* flag, int update = UPDATE_NONE);
 
-    GLAPen& GetPen(int band) const {
+    const GLAPen& GetPen(int band) const {
 	assert(band >= 0 && band < NUM_COLOUR_BANDS);
 	return m_Pens[band];
     }
 
-    GLAPen& GetSurfacePen() const { return m_Pens[NUM_COLOUR_BANDS]; }
+    const GLAPen& GetSurfacePen() const { return m_Pens[NUM_COLOUR_BANDS]; }
 
     int GetNumColourBands() const { return NUM_COLOUR_BANDS; }
 
@@ -431,6 +433,7 @@ public:
 	InvalidateList(LIST_SCALE_BAR);
     }
     void ToggleDegrees() { ToggleFlag(&m_Degrees); }
+    void TogglePercent() { ToggleFlag(&m_Percent); }
     void ToggleTubes() { ToggleFlag(&m_Tubes); }
     void TogglePerspective() { GLACanvas::TogglePerspective(); ForceRefresh(); }
     void ToggleSmoothShading();
@@ -439,6 +442,7 @@ public:
 
     bool GetMetric() const { return m_Metric; }
     bool GetDegrees() const { return m_Degrees; }
+    bool GetPercent() const { return m_Percent; }
     bool GetTubes() const { return m_Tubes; }
 
     bool CheckHitTestGrid(const wxPoint& point, bool centre);
@@ -486,8 +490,9 @@ public:
     void SetColourBy(int colour_by);
     bool ExportMovie(const wxString & fnm);
     void OnPrint(const wxString &filename, const wxString &title,
-		 const wxString &datestamp);
-    void OnExport(const wxString &filename, const wxString &title);
+		 const wxString &datestamp, time_t datestamp_numeric);
+    void OnExport(const wxString &filename, const wxString &title,
+		  const wxString &datestamp, time_t datestamp_numeric);
     void SetCursor(GfxCore::cursor new_cursor);
     bool MeasuringLineActive() const;
 
