@@ -4,7 +4,7 @@
 //  Handlers for events relating to the display of a survey.
 //
 //  Copyright (C) 2000-2002,2005 Mark R. Shinwell
-//  Copyright (C) 2001,2003,2004,2005,2006,2011,2012 Olly Betts
+//  Copyright (C) 2001,2003,2004,2005,2006,2011,2012,2014 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -315,22 +315,19 @@ void GUIControl::OnMouseMove(wxMouseEvent& event)
 void GUIControl::OnLButtonDown(wxMouseEvent& event)
 {
     if (m_View->HasData()) {
-	dragging = LEFT_DRAG;
-
 	m_DragStart = m_DragRealStart = event.GetPosition();
 
 	if (m_View->PointWithinCompass(m_DragStart)) {
 	    m_LastDrag = drag_COMPASS;
+	    m_View->SetCursor(GfxCore::CURSOR_ROTATE_HORIZONTALLY);
 	} else if (m_View->PointWithinClino(m_DragStart)) {
 	    m_LastDrag = drag_ELEV;
+	    m_View->SetCursor(GfxCore::CURSOR_ROTATE_VERTICALLY);
 	} else if (m_View->PointWithinScaleBar(m_DragStart)) {
 	    m_LastDrag = drag_SCALE;
+	    m_View->SetCursor(GfxCore::CURSOR_HORIZONTAL_RESIZE);
 	} else {
-	    if (event.ControlDown()) {
-		if (m_View->IsExtendedElevation()) {
-		    dragging = NO_DRAG;
-		    return;
-		}
+	    if (event.ControlDown() && !m_View->IsExtendedElevation()) {
 		m_View->SetCursor(GfxCore::CURSOR_ROTATE_EITHER_WAY);
 	    } else {
 		m_View->SetCursor(GfxCore::CURSOR_ZOOM_ROTATE);
@@ -340,14 +337,19 @@ void GUIControl::OnLButtonDown(wxMouseEvent& event)
 	    m_ScaleRotateLock = lock_NONE;
 	}
 
+	// We need to release and recapture for the cursor to update (noticed
+	// with wxGTK).
+	if (dragging != NO_DRAG) m_View->ReleaseMouse();
 	m_View->CaptureMouse();
+
+	dragging = LEFT_DRAG;
     }
 }
 
 void GUIControl::OnLButtonUp(wxMouseEvent& event)
 {
     if (m_View->HasData()) {
-	if (dragging == NO_DRAG)
+	if (dragging != LEFT_DRAG)
 	    return;
 
 	if (event.GetPosition() == m_DragRealStart) {
@@ -355,13 +357,22 @@ void GUIControl::OnLButtonUp(wxMouseEvent& event)
 	    m_View->CheckHitTestGrid(m_DragStart, true);
 	}
 
-//	m_View->RedrawIndicators();
+	if (event.MiddleIsDown()) {
+	    OnMButtonDown(event);
+	    return;
+	}
+
+	if (event.RightIsDown()) {
+	    OnRButtonDown(event);
+	    return;
+	}
+
 	m_View->ReleaseMouse();
 
 	m_LastDrag = drag_NONE;
 	dragging = NO_DRAG;
 
-        m_View->DragFinished();
+	m_View->DragFinished();
 
 	if (event.GetPosition() == m_DragRealStart) {
 	    RestoreCursor();
@@ -374,23 +385,39 @@ void GUIControl::OnLButtonUp(wxMouseEvent& event)
 void GUIControl::OnMButtonDown(wxMouseEvent& event)
 {
     if (m_View->HasData() && !m_View->IsExtendedElevation()) {
-	dragging = MIDDLE_DRAG;
 	m_DragStart = event.GetPosition();
 
 	m_View->SetCursor(GfxCore::CURSOR_ROTATE_VERTICALLY);
 
+	// We need to release and recapture for the cursor to update (noticed
+	// with wxGTK).
+	if (dragging != NO_DRAG) m_View->ReleaseMouse();
 	m_View->CaptureMouse();
+	dragging = MIDDLE_DRAG;
     }
 }
 
-void GUIControl::OnMButtonUp(wxMouseEvent&)
+void GUIControl::OnMButtonUp(wxMouseEvent& event)
 {
     if (m_View->HasData()) {
+	if (dragging != MIDDLE_DRAG)
+	    return;
+
+	if (event.LeftIsDown()) {
+	    OnLButtonDown(event);
+	    return;
+	}
+
+	if (event.RightIsDown()) {
+	    OnRButtonDown(event);
+	    return;
+	}
+
 	dragging = NO_DRAG;
 	m_View->ReleaseMouse();
-        m_View->DragFinished();
+	m_View->DragFinished();
 
-        RestoreCursor();
+	RestoreCursor();
     }
 }
 
@@ -402,15 +429,31 @@ void GUIControl::OnRButtonDown(wxMouseEvent& event)
 
 	m_DragStart = event.GetPosition();
 
-	dragging = RIGHT_DRAG;
+	m_View->SetCursor(GfxCore::CURSOR_DRAGGING_HAND);
 
-        m_View->SetCursor(GfxCore::CURSOR_DRAGGING_HAND);
+	// We need to release and recapture for the cursor to update (noticed
+	// with wxGTK).
+	if (dragging != NO_DRAG) m_View->ReleaseMouse();
 	m_View->CaptureMouse();
+	dragging = RIGHT_DRAG;
     }
 }
 
-void GUIControl::OnRButtonUp(wxMouseEvent&)
+void GUIControl::OnRButtonUp(wxMouseEvent& event)
 {
+    if (dragging != RIGHT_DRAG)
+	return;
+
+    if (event.LeftIsDown()) {
+	OnLButtonDown(event);
+	return;
+    }
+
+    if (event.MiddleIsDown()) {
+	OnMButtonDown(event);
+	return;
+    }
+
     m_LastDrag = drag_NONE;
     m_View->ReleaseMouse();
 
@@ -1028,6 +1071,20 @@ void GUIControl::OnToggleDegreesUpdate(wxUpdateUIEvent& cmd)
     cmd.Check(m_View->GetDegrees());
 }
 
+void GUIControl::OnTogglePercent()
+{
+    m_View->TogglePercent();
+
+    wxConfigBase::Get()->Write(wxT("percent"), m_View->GetPercent());
+    wxConfigBase::Get()->Flush();
+}
+
+void GUIControl::OnTogglePercentUpdate(wxUpdateUIEvent& cmd)
+{
+    cmd.Enable(m_View->HasData());
+    cmd.Check(m_View->GetPercent());
+}
+
 void GUIControl::OnToggleTubes()
 {
     m_View->ToggleTubes();
