@@ -1,6 +1,6 @@
 /* listpos.c
  * SURVEX Cave surveying software: stuff to do with stn position output
- * Copyright (C) 1991-2002,2011,2012 Olly Betts
+ * Copyright (C) 1991-2002,2011,2012,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,12 +64,8 @@ traverse_prefix_tree(prefix *from, void (*fn)(prefix *))
    }
 }
 
-#if NODESTAT
-static int *cOrder;
-static int icOrderMac;
-
 static void
-node_stat(prefix *p)
+check_node(prefix *p)
 {
    if (!p->pos) {
       if (!TSTBIT(p->sflags, SFLAGS_SURVEY)) {
@@ -88,27 +84,7 @@ node_stat(prefix *p)
 	 }
       }
    } else {
-      int order;
-      SVX_ASSERT(pfx_fixed(p));
-
-      order = p->shape;
-
-      if (order >= icOrderMac) {
-	 int c = order * 2;
-	 cOrder = osrealloc(cOrder, c * ossizeof(int));
-	 while (icOrderMac < c) cOrder[icOrderMac++] = 0;
-      }
-      cOrder[order]++;
-
-      if (TSTBIT(p->sflags, SFLAGS_SUSPECTTYPO)) {
-	 warning_in_file(p->filename, p->line,
-		 /*Station “%s” referred to just once, with an explicit prefix - typo?*/70,
-		 sprint_prefix(p));
-      }
-
-      /* Don't need to worry about export violations in hanging surveys -
-       * if there are hanging surveys then we give up in articulate()
-       * and never get here... */
+      /* Do we need to worry about export violations in hanging surveys? */
       if (fExportUsed) {
 #if 0
 	 printf("L min %d max %d pfx %s\n",
@@ -139,16 +115,50 @@ node_stat(prefix *p)
 	    osfree(s);
 	 }
       }
+
+      if (TSTBIT(p->sflags, SFLAGS_SUSPECTTYPO)) {
+	 warning_in_file(p->filename, p->line,
+		 /*Station “%s” referred to just once, with an explicit prefix - typo?*/70,
+		 sprint_prefix(p));
+      }
    }
 }
 
+#if NODESTAT
+static int *cOrder;
+static int icOrderMac;
+
+static void
+node_stat(prefix *p)
+{
+   if (p->pos) {
+      int order;
+      SVX_ASSERT(pfx_fixed(p));
+
+      order = p->shape;
+
+      if (order >= icOrderMac) {
+	 int c = order * 2;
+	 cOrder = osrealloc(cOrder, c * ossizeof(int));
+	 while (icOrderMac < c) cOrder[icOrderMac++] = 0;
+      }
+      cOrder[order]++;
+   }
+
+   check_node(p);
+}
+
 static void
 node_stats(prefix *from)
 {
+   prefix * p;
    icOrderMac = 8; /* Start value */
    cOrder = osmalloc(icOrderMac * ossizeof(int));
    memset(cOrder, 0, icOrderMac * ossizeof(int));
    traverse_prefix_tree(from, node_stat);
+   for (p = anon_list; p; p = p->right) {
+      node_stat(p);
+   }
 }
 #endif
 
@@ -157,12 +167,26 @@ print_node_stats(void)
 {
 #if NODESTAT
    int c;
+   int max_c = 9999; /* Always allow space for 4 digits. */
+   int width;
    node_stats(root);
+   for (c = 0; c < icOrderMac; c++) {
+      if (cOrder[c] > max_c) {
+	 max_c = cOrder[c];
+      }
+   }
+   width = 1 + (int)log10((double)max_c);
    for (c = 0; c < icOrderMac; c++) {
       if (cOrder[c] > 0) {
-	 printf("%4d %d-%s.\n", cOrder[c], c,
+	 printf("%*d %d-%s.\n", width, cOrder[c], c,
 		msg(cOrder[c] == 1 ? /*node*/176 : /*nodes*/177));
       }
    }
 #endif
 }
+
+extern void
+check_node_stats(void)
+{
+   traverse_prefix_tree(root, check_node);
+}
