@@ -1,6 +1,6 @@
 //  log.h - Error log window for Aven.
 //
-//  Copyright (C) 2006 Olly Betts
+//  Copyright (C) 2006,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,5 +24,9 @@ class MyLogWindow : public wxLogWindow {
   public:
     MyLogWindow();
   protected:
+#if wxCHECK_VERSION(2,9,0)
+    void DoLogText(const wxChar *msg);
+#else
     void DoLogString(const wxChar *msg, time_t timestamp);
+#endif
 };
