@@ -4,7 +4,7 @@
 //  Main frame handling for Aven.
 //
 //  Copyright (C) 2000-2002,2005,2006 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011,2012,2013 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011,2012,2013,2014 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -563,6 +563,7 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_MENU(menu_CTL_SIDE_PANEL, MainFrm::OnViewSidePanel)
     EVT_MENU(menu_CTL_METRIC, MainFrm::OnToggleMetric)
     EVT_MENU(menu_CTL_DEGREES, MainFrm::OnToggleDegrees)
+    EVT_MENU(menu_CTL_PERCENT, MainFrm::OnTogglePercent)
     EVT_MENU(menu_CTL_REVERSE, MainFrm::OnReverseControls)
     EVT_MENU(menu_CTL_CANCEL_DIST_LINE, MainFrm::OnCancelDistLine)
     EVT_MENU(wxID_ABOUT, MainFrm::OnAbout)
@@ -625,6 +626,7 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
     EVT_UPDATE_UI(menu_CTL_CANCEL_DIST_LINE, MainFrm::OnCancelDistLineUpdate)
     EVT_UPDATE_UI(menu_CTL_METRIC, MainFrm::OnToggleMetricUpdate)
     EVT_UPDATE_UI(menu_CTL_DEGREES, MainFrm::OnToggleDegreesUpdate)
+    EVT_UPDATE_UI(menu_CTL_PERCENT, MainFrm::OnTogglePercentUpdate)
 END_EVENT_TABLE()
 
 class LabelCmp : public greater<const LabelInfo*> {
@@ -687,6 +689,7 @@ DnDFile::OnDropFiles(wxCoord, wxCoord, const wxArrayString &filenames)
 
 MainFrm::MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size) :
     wxFrame(NULL, 101, title, pos, size, wxDEFAULT_FRAME_STYLE),
+    m_SashPosition(-1),
     m_Gfx(NULL), m_NumEntrances(0), m_NumFixedPts(0), m_NumExportedPts(0),
     m_NumHighlighted(0),
     m_HasUndergroundLegs(false), m_HasSplays(false), m_HasSurfaceLegs(false),
@@ -865,6 +868,7 @@ void MainFrm::CreateMenuBar()
     ctlmenu->AppendSeparator();
     ctlmenu->AppendCheckItem(menu_CTL_METRIC, wmsg(/*&Metric*/342));
     ctlmenu->AppendCheckItem(menu_CTL_DEGREES, wmsg(/*&Degrees*/343));
+    ctlmenu->AppendCheckItem(menu_CTL_PERCENT, wmsg(/*&Percent*/430));
 #endif
 
     wxMenuBar* menubar = new wxMenuBar();
@@ -1334,17 +1338,14 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
 
     separator = survey->separator;
     m_Title = wxString(survey->title, wxConvUTF8);
+    m_DateStamp_numeric = survey->datestamp_numeric;
     if (strcmp(survey->datestamp, "?") == 0) {
 	m_DateStamp = wmsg(/*Date and time not available.*/108);
     } else if (survey->datestamp[0] == '@') {
-	char * end;
-	time_t t = (time_t)strtol(survey->datestamp + 1, &end, 10);
-	if (*end == '\0') {
-	    const struct tm * tm = localtime(&t);
-	    char buf[256];
-	    strftime(buf, 256, msg(/*%a,%Y.%m.%d %H:%M:%S %Z*/107), tm);
-	    m_DateStamp = wxString(buf, wxConvUTF8);
-	}
+	const struct tm * tm = localtime(&m_DateStamp_numeric);
+	char buf[256];
+	strftime(buf, 256, msg(/*%a,%Y.%m.%d %H:%M:%S %Z*/107), tm);
+	m_DateStamp = wxString(buf, wxConvUTF8);
     }
     if (m_DateStamp.empty()) {
 	m_DateStamp = wxString(survey->datestamp, wxConvUTF8);
@@ -1598,11 +1599,6 @@ void MainFrm::FillTree()
     m_Tree->SetEnabled();
 }
 
-void MainFrm::SelectTreeItem(LabelInfo* label)
-{
-    m_Tree->SelectItem(label->tree_id);
-}
-
 void MainFrm::CentreDataset(const Vector3 & vmin)
 {
     // Centre the dataset around the origin.
@@ -1714,15 +1710,19 @@ void MainFrm::OpenFile(const wxString& file, wxString survey)
 
 void MainFrm::InitialiseAfterLoad(const wxString & file)
 {
-    int x;
-    int y;
-    GetClientSize(&x, &y);
-    if (x < 600)
-	x /= 3;
-    else if (x < 1000)
-	x = 200;
-    else
-	x /= 5;
+    if (m_SashPosition < 0) {
+	// Calculate sane default width for side panel.
+	int x;
+	int y;
+	GetClientSize(&x, &y);
+	if (x < 600)
+	    x /= 3;
+	else if (x < 1000)
+	    x = 200;
+	else
+	    x /= 5;
+	m_SashPosition = x;
+    }
 
     // Do this before we potentially delete the log window which may own the
     // wxString which parameter file refers to!
@@ -1755,11 +1755,16 @@ void MainFrm::InitialiseAfterLoad(const wxString & file)
 	if (win == m_Gfx) win = NULL;
     }
 
-    m_Splitter->SplitVertically(m_Notebook, m_Gfx, x);
-    m_SashPosition = x; // Save width of panel.
+    if (!IsFullScreen()) {
+	m_Splitter->SplitVertically(m_Notebook, m_Gfx, m_SashPosition);
+    } else {
+	was_showing_sidepanel_before_fullscreen = true;
+    }
 
     m_Gfx->Initialise(same_file);
-    m_Notebook->Show(true);
+    if (!IsFullScreen()) {
+	m_Notebook->Show(true);
+    }
 
     m_Gfx->Show(true);
     m_Gfx->SetFocus();
@@ -1785,13 +1790,13 @@ void MainFrm::OnOpen(wxCommandEvent&)
     wxString filetypes = wxT("*.3d");
 #else
     wxString filetypes;
-    filetypes.Printf(wxT("%s|*.3d;*.svx;*.plt;*.plf;*.dat;*.mak;*.xyz"
-		     CASE("*.3D;*.SVX;*.PLT;*.PLF;*.DAT;*.MAK;*.XYZ")
+    filetypes.Printf(wxT("%s|*.3d;*.svx;*.plt;*.plf;*.dat;*.mak;*.adj;*.sht;*.una;*.xyz"
+		     CASE("*.3D;*.SVX;*.PLT;*.PLF;*.DAT;*.MAK;*.ADJ;*.SHT;*.UNA;*.XYZ")
 		     "|%s|*.3d"CASE("*.3D")
 		     "|%s|*.svx"CASE("*.SVX")
 		     "|%s|*.plt;*.plf"CASE("*.PLT;*.PLF")
 		     "|%s|*.dat;*.mak"CASE("*.DAT;*.MAK")
-		     "|%s|*.xyz"CASE("*.XYZ")
+		     "|%s|*.adj;*.sht;*.una;*.xyz"CASE("*.ADJ;*.SHT;*.UNA;*.XYZ")
 		     "|%s|%s"),
 		     wmsg(/*All survey files*/229).c_str(),
 		     wmsg(/*Survex 3d files*/207).c_str(),
@@ -1849,7 +1854,7 @@ void MainFrm::OnFilePreferences(wxCommandEvent&)
 
 void MainFrm::OnPrint(wxCommandEvent&)
 {
-    m_Gfx->OnPrint(m_File, m_Title, m_DateStamp);
+    m_Gfx->OnPrint(m_File, m_Title, m_DateStamp, m_DateStamp_numeric);
 }
 
 void MainFrm::OnPageSetup(wxCommandEvent&)
@@ -1862,7 +1867,7 @@ void MainFrm::OnPageSetup(wxCommandEvent&)
 
 void MainFrm::OnExport(wxCommandEvent&)
 {
-    m_Gfx->OnExport(m_File, m_Title);
+    m_Gfx->OnExport(m_File, m_Title, m_DateStamp, m_DateStamp_numeric);
 }
 
 void MainFrm::OnQuit(wxCommandEvent&)
@@ -1938,16 +1943,22 @@ void MainFrm::ClearCoords()
 
 void MainFrm::SetCoords(const Vector3 &v)
 {
-    wxString & s = coords_text;
+    Double x = v.GetX();
+    Double y = v.GetY();
+    Double z = v.GetZ();
+    int units;
     if (m_Gfx->GetMetric()) {
-	s.Printf(wmsg(/*%.2f E, %.2f N*/338), v.GetX(), v.GetY());
-	s += wxString::Format(wxT(", %s %.2fm"), wmsg(/*Altitude*/335).c_str(), v.GetZ());
+	units = /*m*/424;
     } else {
-	s.Printf(wmsg(/*%.2f E, %.2f N*/338),
-		 v.GetX() / METRES_PER_FOOT, v.GetY() / METRES_PER_FOOT);
-	s += wxString::Format(wxT(", %s %.2fft"), wmsg(/*Altitude*/335).c_str(),
-			      v.GetZ() / METRES_PER_FOOT);
+	x /= METRES_PER_FOOT;
+	y /= METRES_PER_FOOT;
+	z /= METRES_PER_FOOT;
+	units = /*ft*/428;
     }
+    coords_text.Printf(wmsg(/*%.2f E, %.2f N*/338), x, y);
+    coords_text += wxString::Format(wxT(", %s %.2f%s"),
+				    wmsg(/*Altitude*/335).c_str(),
+				    z, wmsg(units).c_str());
     distfree_text = wxString();
     UpdateStatusBar();
 }
@@ -1985,22 +1996,24 @@ void MainFrm::SetCoords(Double x, Double y)
 	wxString from_str;
 	from_str.Printf(wmsg(/*From %s*/339), label->GetText().c_str());
 
-	wxString brg_unit;
+	int brg_unit;
 	if (m_Gfx->GetDegrees()) {
-	    brg_unit = wmsg(/*°*/344);
+	    brg_unit = /*°*/344;
 	} else {
 	    brg *= 400.0 / 360.0;
-	    brg_unit = wmsg(/*grad*/345);
+	    brg_unit = /*grad*/345;
 	}
 
+	int units;
 	if (m_Gfx->GetMetric()) {
-	    t.Printf(wmsg(/*%s: H %.2f%s, Brg %03d%s*/374),
-		     from_str.c_str(), dh, wxT("m"), int(brg), brg_unit.c_str());
+	    units = /*m*/424;
 	} else {
-	    t.Printf(wmsg(/*%s: H %.2f%s, Brg %03d%s*/374),
-		     from_str.c_str(), dh / METRES_PER_FOOT, wxT("ft"), int(brg),
-		     brg_unit.c_str());
+	    dh /= METRES_PER_FOOT;
+	    units = /*ft*/428;
 	}
+	t.Printf(wmsg(/*%s: H %.2f%s, Brg %03d%s*/374),
+		 from_str.c_str(), dh, wmsg(units).c_str(),
+		 int(brg), wmsg(brg_unit).c_str());
     }
 
     UpdateStatusBar();
@@ -2008,12 +2021,16 @@ void MainFrm::SetCoords(Double x, Double y)
 
 void MainFrm::SetAltitude(Double z)
 {
-    wxString & s = coords_text;
+    double alt = z;
+    int units;
     if (m_Gfx->GetMetric()) {
-	s.Printf(wxT("%s %.2fm"), wmsg(/*Altitude*/335).c_str(), double(z));
+	units = /*m*/424;
     } else {
-	s.Printf(wxT("%s %.2fft"), wmsg(/*Altitude*/335).c_str(), double(z / METRES_PER_FOOT));
+	alt /= METRES_PER_FOOT;
+	units = /*ft*/428;
     }
+    coords_text.Printf(wxT("%s %.2f%s"), wmsg(/*Altitude*/335).c_str(),
+		       alt, wmsg(units).c_str());
 
     wxString & t = distfree_text;
     t = wxString();
@@ -2024,13 +2041,11 @@ void MainFrm::SetAltitude(Double z)
 	wxString from_str;
 	from_str.Printf(wmsg(/*From %s*/339), label->GetText().c_str());
 
-	if (m_Gfx->GetMetric()) {
-	    t.Printf(wmsg(/*%s: V %.2f%s*/375),
-		     from_str.c_str(), dz, wxT("m"));
-	} else {
-	    t.Printf(wmsg(/*%s: V %.2f%s*/375),
-		     from_str.c_str(), dz / METRES_PER_FOOT, wxT("ft"));
+	if (!m_Gfx->GetMetric()) {
+	    dz /= METRES_PER_FOOT;
 	}
+	t.Printf(wmsg(/*%s: V %.2f%s*/375), from_str.c_str(),
+		 dz, wmsg(units).c_str());
     }
 
     UpdateStatusBar();
@@ -2053,15 +2068,21 @@ void MainFrm::ShowInfo(const LabelInfo *here)
 
     Vector3 v = *here + m_Offsets;
     wxString & s = here_text;
+    Double x = v.GetX();
+    Double y = v.GetY();
+    Double z = v.GetZ();
+    int units;
     if (m_Gfx->GetMetric()) {
-	s.Printf(wmsg(/*%.2f E, %.2f N*/338), v.GetX(), v.GetY());
-	s += wxString::Format(wxT(", %s %.2fm"), wmsg(/*Altitude*/335).c_str(), v.GetZ());
+	units = /*m*/424;
     } else {
-	s.Printf(wmsg(/*%.2f E, %.2f N*/338),
-		 v.GetX() / METRES_PER_FOOT, v.GetY() / METRES_PER_FOOT);
-	s += wxString::Format(wxT(", %s %.2fft"), wmsg(/*Altitude*/335).c_str(),
-			      v.GetZ() / METRES_PER_FOOT);
+	x /= METRES_PER_FOOT;
+	y /= METRES_PER_FOOT;
+	z /= METRES_PER_FOOT;
+	units = /*ft*/428;
     }
+    s.Printf(wmsg(/*%.2f E, %.2f N*/338), x, y);
+    s += wxString::Format(wxT(", %s %.2f%s"), wmsg(/*Altitude*/335).c_str(),
+			  z, wmsg(units).c_str());
     s += wxT(": ");
     s += here->GetText();
     m_Gfx->SetHere(*here);
@@ -2081,32 +2102,29 @@ void MainFrm::ShowInfo(const LabelInfo *here)
 	from_str.Printf(wmsg(/*From %s*/339), label->GetText().c_str());
 
 	wxString hv_str;
+	z = v.GetZ();
 	if (m_Gfx->GetMetric()) {
-	    hv_str.Printf(wmsg(/*H %.2f%s, V %.2f%s*/340),
-			  d_horiz, wxT("m"), delta.GetZ(), wxT("m"));
+	    units = /*m*/424;
 	} else {
-	    hv_str.Printf(wmsg(/*H %.2f%s, V %.2f%s*/340),
-			  d_horiz / METRES_PER_FOOT, wxT("ft"),
-			  delta.GetZ() / METRES_PER_FOOT, wxT("ft"));
+	    d_horiz /= METRES_PER_FOOT;
+	    dr /= METRES_PER_FOOT;
+	    z /= METRES_PER_FOOT;
+	    units = /*ft*/428;
 	}
-	wxString brg_unit;
+	wxString len_unit = wmsg(units);
+	hv_str.Printf(wmsg(/*H %.2f%s, V %.2f%s*/340),
+		      d_horiz, len_unit.c_str(), z, len_unit.c_str());
+	int brg_unit;
 	if (m_Gfx->GetDegrees()) {
-	    brg_unit = wmsg(/*°*/344);
+	    brg_unit = /*°*/344;
 	} else {
 	    brg *= 400.0 / 360.0;
-	    brg_unit = wmsg(/*grad*/345);
+	    brg_unit = /*grad*/345;
 	}
 	wxString & d = dist_text;
-	if (m_Gfx->GetMetric()) {
-	    d.Printf(wmsg(/*%s: %s, Dist %.2f%s, Brg %03d%s*/341),
-		     from_str.c_str(), hv_str.c_str(),
-		     dr, wxT("m"), int(brg), brg_unit.c_str());
-	} else {
-	    d.Printf(wmsg(/*%s: %s, Dist %.2f%s, Brg %03d%s*/341),
-		     from_str.c_str(), hv_str.c_str(),
-		     dr / METRES_PER_FOOT, wxT("ft"), int(brg),
-		     brg_unit.c_str());
-	}
+	d.Printf(wmsg(/*%s: %s, Dist %.2f%s, Brg %03d%s*/341),
+		 from_str.c_str(), hv_str.c_str(),
+		 dr, len_unit.c_str(), int(brg), wmsg(brg_unit).c_str());
 	m_Gfx->SetThere(*label);
     } else {
 	dist_text = wxString();
@@ -2565,7 +2583,8 @@ bool MainFrm::ShowingSidePanel()
 
 void MainFrm::ViewFullScreen() {
     ShowFullScreen(!IsFullScreen());
-    static bool sidepanel;
-    if (IsFullScreen()) sidepanel = ShowingSidePanel();
-    if (sidepanel) ToggleSidePanel();
+    if (IsFullScreen())
+	was_showing_sidepanel_before_fullscreen = ShowingSidePanel();
+    if (was_showing_sidepanel_before_fullscreen)
+	ToggleSidePanel();
 }
