@@ -4,7 +4,7 @@
 //  Main frame handling for Aven.
 //
 //  Copyright (C) 2000-2003,2005 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011,2012,2013 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011,2012,2013,2014 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 using namespace std;
 
 #include <math.h>
+#include <time.h>
 
 #define MARK_FIRST 1
 #define MARK_NEXT 2
@@ -122,6 +123,7 @@ enum {
     menu_CTL_SIDE_PANEL,
     menu_CTL_METRIC,
     menu_CTL_DEGREES,
+    menu_CTL_PERCENT,
     menu_CTL_REVERSE,
     menu_CTL_CANCEL_DIST_LINE,
     textctrl_FIND,
@@ -215,6 +217,7 @@ class traverse : public vector<PointInfo> {
 class MainFrm : public wxFrame {
     wxFileHistory m_history;
     int m_SashPosition;
+    bool was_showing_sidepanel_before_fullscreen;
     list<traverse> traverses;
     list<traverse> surface_traverses;
     list<vector<XSect> > tubes;
@@ -241,6 +244,7 @@ class MainFrm : public wxFrame {
     AvenPresList* m_PresList;
     wxString m_File;
     wxString m_Title, m_DateStamp;
+    time_t m_DateStamp_numeric;
     wxChar separator; // character separating survey levels (often '.')
     Vector3 m_Offsets;
 
@@ -446,10 +450,12 @@ public:
 
     void OnToggleMetric(wxCommandEvent&) { if (m_Control) m_Control->OnToggleMetric(); }
     void OnToggleDegrees(wxCommandEvent&) { if (m_Control) m_Control->OnToggleDegrees(); }
+    void OnTogglePercent(wxCommandEvent&) { if (m_Control) m_Control->OnTogglePercent(); }
     void OnToggleTubes(wxCommandEvent&) { if (m_Control) m_Control->OnToggleTubes(); }
 
     void OnToggleMetricUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnToggleMetricUpdate(event); }
     void OnToggleDegreesUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnToggleDegreesUpdate(event); }
+    void OnTogglePercentUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnTogglePercentUpdate(event); }
     void OnToggleTubesUpdate(wxUpdateUIEvent& event) { if (m_Control) m_Control->OnToggleTubesUpdate(event); }
 
     // end of horrible bodges
@@ -471,7 +477,10 @@ public:
     int GetDateExtent() const { return m_DateExt; }
     int GetDateMin() const { return m_DateMin; }
 
-    void SelectTreeItem(LabelInfo* label);
+    void SelectTreeItem(LabelInfo* label) {
+	if (label->tree_id.IsOk())
+	    m_Tree->SelectItem(label->tree_id);
+    }
     void ClearTreeSelection();
 
     int GetNumFixedPts() const { return m_NumFixedPts; }
