@@ -1,6 +1,6 @@
 /* message.c
  * Fairly general purpose message and error routines
- * Copyright (C) 1993-2003,2004,2005,2006,2007,2010,2011,2012 Olly Betts
+ * Copyright (C) 1993-2003,2004,2005,2006,2007,2010,2011,2012,2014 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1051,10 +1051,27 @@ macosx_got_msg:
 	 msg_lang = "en";
 #endif
 #if OS_WIN32
-	 locid = GetUserDefaultLCID();
+	 /* GetUserDefaultUILanguage() requires Microsoft Windows 2000 or
+	  * newer.  For older versions, we use GetUserDefaultLCID().
+	  */
+	 {
+	    HMODULE win32 = GetModuleHandle(TEXT("kernel32.dll"));
+	    FARPROC f = GetProcAddress(win32, "GetUserDefaultUILanguage");
+	    if (f) {
+	       typedef LANGID (WINAPI *func_GetUserDefaultUILanguage)(void);
+	       func_GetUserDefaultUILanguage g;
+	       g = (func_GetUserDefaultUILanguage)f;
+	       locid = g();
+	    } else {
+	       locid = GetUserDefaultLCID();
+	    }
+	 }
 	 if (locid) {
 	    WORD langid = LANGIDFROMLCID(locid);
 	    switch (PRIMARYLANGID(langid)) {
+	     case LANG_BULGARIAN:
+	       msg_lang = "bg";
+	       break;
 /* older mingw compilers don't seem to supply this value */
 #ifndef LANG_CATALAN
 # define LANG_CATALAN 0x03
@@ -1086,6 +1103,9 @@ macosx_got_msg:
 		  msg_lang = "de";
 	       }
 	       break;
+	     case LANG_INDONESIAN:
+	       msg_lang = "id";
+	       break;
 	     case LANG_ITALIAN:
 	       msg_lang = "it";
 	       break;
