@@ -3,7 +3,7 @@
 //
 //  Class for writing movies from Aven.
 //
-//  Copyright (C) 2004,2011,2012,2013 Olly Betts
+//  Copyright (C) 2004,2011,2012,2013,2014 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -77,9 +77,10 @@ extern "C" {
 #  define avio_close url_fclose
 # endif
 # ifndef HAVE_AVCODEC_FREE_FRAME
-static inline void avcodec_free_frame(AVFrame * frame) {
-    free(frame->data[0]);
-    free(frame);
+static inline void avcodec_free_frame(AVFrame ** frame) {
+    free((*frame)->data[0]);
+    free(*frame);
+    *frame = NULL
 }
 # endif
 # ifndef HAVE_AVCODEC_OPEN2
@@ -107,14 +108,15 @@ static inline void avcodec_free_frame(AVFrame * frame) {
 enum {
     MOVIE_NO_SUITABLE_FORMAT = 1,
     MOVIE_AUDIO_ONLY,
-    MOVIE_FILENAME_TOO_LONG,
-    MOVIE_NOT_ENABLED
+    MOVIE_FILENAME_TOO_LONG
 };
 
 const int OUTBUF_SIZE = 200000;
 
 MovieMaker::MovieMaker()
+#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
     : oc(0), video_st(0), frame(0), outbuf(0), pixels(0), sws_ctx(0), averrno(0)
+#endif
 {
 #ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
     static bool initialised_ffmpeg = false;
@@ -188,6 +190,7 @@ bool MovieMaker::Open(const char *fnm, int width, int height)
     c->time_base.num = 1;
     c->gop_size = 12; /* emit one intra frame every twelve frames at most */
     c->pix_fmt = AV_PIX_FMT_YUV420P;
+    c->rc_buffer_size = c->bit_rate * 4; // Enough for 4 seconds
     // B frames are backwards predicted - they can improve compression,
     // but may slow encoding and decoding.
     // if (c->codec_id == AV_CODEC_ID_MPEG2VIDEO) {
@@ -287,7 +290,6 @@ bool MovieMaker::Open(const char *fnm, int width, int height)
     (void)fnm;
     (void)width;
     (void)height;
-    averrno = MOVIE_NOT_ENABLED;
     return false;
 #endif
 }
@@ -302,8 +304,8 @@ unsigned char * MovieMaker::GetBuffer() const {
 }
 
 int MovieMaker::GetWidth() const {
-    assert(video_st);
 #ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
+    assert(video_st);
     AVCodecContext *c = video_st->codec;
     return c->width;
 #else
@@ -312,8 +314,8 @@ int MovieMaker::GetWidth() const {
 }
 
 int MovieMaker::GetHeight() const {
-    assert(video_st);
 #ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
+    assert(video_st);
     AVCodecContext *c = video_st->codec;
     return c->height;
 #else
@@ -351,9 +353,10 @@ bool MovieMaker::AddFrame()
 
     // Encode this frame.
 #ifdef HAVE_AVCODEC_ENCODE_VIDEO2
-    AVPacket pkt = { 0 };
+    AVPacket pkt;
     int got_packet;
     av_init_packet(&pkt);
+    pkt.data = NULL;
 
     int ret = avcodec_encode_video2(c, &pkt, frame, &got_packet);
     if (ret < 0) {
@@ -362,11 +365,11 @@ bool MovieMaker::AddFrame()
     }
     if (got_packet && pkt.size) {
 	// Write the compressed frame to the media file.
-	if (pkt.pts != AV_NOPTS_VALUE) {
+	if (pkt.pts != int64_t(AV_NOPTS_VALUE)) {
 	    pkt.pts = av_rescale_q(pkt.pts,
 				   c->time_base, video_st->time_base);
 	}
-	if (pkt.dts != AV_NOPTS_VALUE) {
+	if (pkt.dts != int64_t(AV_NOPTS_VALUE)) {
 	    pkt.dts = av_rescale_q(pkt.dts,
 				   c->time_base, video_st->time_base);
 	}
@@ -419,9 +422,10 @@ MovieMaker::Close()
 
 #ifdef HAVE_AVCODEC_ENCODE_VIDEO2
 	while (1) {
-	    AVPacket pkt = { 0 };
+	    AVPacket pkt;
 	    int got_packet;
 	    av_init_packet(&pkt);
+	    pkt.data = NULL;
 
 	    int ret = avcodec_encode_video2(c, &pkt, NULL, &got_packet);
 	    if (ret < 0) {
@@ -433,11 +437,11 @@ MovieMaker::Close()
 	    if (!pkt.size) continue;
 
 	    // Write the compressed frame to the media file.
-	    if (pkt.pts != AV_NOPTS_VALUE) {
+	    if (pkt.pts != int64_t(AV_NOPTS_VALUE)) {
 		pkt.pts = av_rescale_q(pkt.pts,
 				       c->time_base, video_st->time_base);
 	    }
-	    if (pkt.dts != AV_NOPTS_VALUE) {
+	    if (pkt.dts != int64_t(AV_NOPTS_VALUE)) {
 		pkt.dts = av_rescale_q(pkt.dts,
 				       c->time_base, video_st->time_base);
 	    }
@@ -486,10 +490,10 @@ MovieMaker::Close()
     return true;
 }
 
+#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
 void
 MovieMaker::release()
 {
-#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
     if (video_st) {
 	// Close codec.
 	avcodec_close(video_st->codec);
@@ -497,8 +501,7 @@ MovieMaker::release()
     }
 
     if (frame) {
-	avcodec_free_frame(frame);
-	frame = NULL;
+	avcodec_free_frame(&frame);
     }
     free(pixels);
     pixels = NULL;
@@ -523,12 +526,14 @@ MovieMaker::release()
 	av_free(oc);
 	oc = NULL;
     }
-#endif
 }
+#endif
 
 MovieMaker::~MovieMaker()
 {
+#ifdef HAVE_LIBAVFORMAT_AVFORMAT_H
     release();
+#endif
 }
 
 const char *
@@ -563,8 +568,6 @@ MovieMaker::get_error_string() const
 	    return "Audio-only format specified";
 	case MOVIE_FILENAME_TOO_LONG:
 	    return "Filename too long";
-	case MOVIE_NOT_ENABLED:
-	    return "Movie export support not included";
     }
     return "Unknown error";
 #else
