@@ -1,6 +1,6 @@
 /* netartic.c
  * Split up network at articulation points
- * Copyright (C) 1993-2003,2005 Olly Betts
+ * Copyright (C) 1993-2003,2005,2012 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "debug.h"
 #include "cavern.h"
 #include "filename.h"
+#include "listpos.h"
 #include "message.h"
 #include "netartic.h"
 #include "netbits.h"
@@ -366,6 +367,15 @@ articulate(void)
    }
 
    if (stnlist) {
+      /* Any stations still in stnlist are unfixed, which is means we have
+       * one or more hanging surveys.
+       *
+       * The cause of the problem is pretty likely to be a typo, so run the
+       * checks which report errors and warnings about issues which such a
+       * typo is likely to result in.
+       */
+      check_node_stats();
+
       /* Actually this error is fatal, but we want to list the survey
        * stations which aren't connected, so we report it as an error
        * and die after listing them...
@@ -373,6 +383,11 @@ articulate(void)
       bool fNotAttached = fFalse;
       error(/*Survey not all connected to fixed stations*/45);
       FOR_EACH_STN(stn, stnlist) {
+	 /* Anonymous stations must be at the end of a trailing traverse (since
+	  * the same anonymous station can't be referred to more than once),
+	  * and trailing traverses have been removed at this point.
+	  */
+	 SVX_ASSERT(!TSTBIT(stn->name->sflags, SFLAGS_ANON));
 	 if (stn->name->ident) {
 	    if (!fNotAttached) {
 	       fNotAttached = fTrue;
@@ -449,7 +464,7 @@ articulate(void)
    FOR_EACH_STN(stn, stnlist) {
       int d;
       int f;
-      if (stn->name->ident && stn->name->sflags & BIT(SFLAGS_FIXED)) {
+      if (stn->name->ident && TSTBIT(stn->name->sflags, SFLAGS_FIXED)) {
 	 stn->colour = 1;
       } else {
 	 stn->colour = 0;
