@@ -1,6 +1,6 @@
 /* netbits.c
  * Miscellaneous primitive network routines for Survex
- * Copyright (C) 1992-2003,2006,2011 Olly Betts
+ * Copyright (C) 1992-2003,2006,2011,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -269,7 +269,6 @@ addleg_(node *fr, node *to,
 {
    int i, j;
    linkfor *leg, *leg2;
-   int shape;
    /* we have been asked to add a leg with the same node at both ends
     * - this should be trapped by the caller */
    SVX_ASSERT(fr->name != to->name);
@@ -301,20 +300,15 @@ addleg_(node *fr, node *to,
    leg2->l.reverse = i;
    leg->l.reverse = j | FLAG_DATAHERE | leg_flags;
 
-   leg->l.flags = pcs->flags;
+   leg->l.flags = pcs->flags | (pcs->style << FLAGS_STYLE_BIT0);
    leg->meta = pcs->meta;
    if (pcs->meta) ++pcs->meta->ref_count;
 
    fr->leg[i] = leg;
    to->leg[j] = leg2;
 
-   shape = fr->name->shape + 1;
-   if (shape < 1) shape = 1 - shape;
-   fr->name->shape = shape;
-
-   shape = to->name->shape + 1;
-   if (shape < 1) shape = 1 - shape;
-   to->name->shape = shape;
+   ++fr->name->shape;
+   ++to->name->shape;
 }
 
 /* Add a leg between names *fr_name and *to_name
@@ -505,7 +499,7 @@ freeleg(node **stnptr)
    leg->v[0] = leg->v[1] = leg->v[2] = (real)0.0;
 #endif
    leg->l.reverse = 1 | FLAG_DATAHERE | FLAG_FAKE;
-   leg->l.flags = pcs->flags;
+   leg->l.flags = pcs->flags | (pcs->style << FLAGS_STYLE_BIT0);
 
    leg2->l.to = oldstn;
    leg2->l.reverse = 0;
@@ -547,6 +541,14 @@ extern void
 fprint_prefix(FILE *fh, const prefix *ptr)
 {
    SVX_ASSERT(ptr);
+   if (TSTBIT(ptr->sflags, SFLAGS_ANON)) {
+      /* We release the stations, so ptr->stn is NULL late on, so we can't
+       * use that to print "anonymous station surveyed from somesurvey.12"
+       * here.  FIXME */
+      fputs("anonymous station", fh);
+      /* FIXME: if ident is set, show it? */
+      return;
+   }
    if (ptr->up != NULL) {
       fprint_prefix(fh, ptr->up);
       if (ptr->up->up != NULL) fputc('.', fh);
@@ -581,6 +583,14 @@ sprint_prefix(const prefix *ptr)
 {
    SVX_ASSERT(ptr);
    if (!buffer) buffer = osmalloc(buffer_len);
+   if (TSTBIT(ptr->sflags, SFLAGS_ANON)) {
+      /* We release the stations, so ptr->stn is NULL late on, so we can't
+       * use that to print "anonymous station surveyed from somesurvey.12"
+       * here.  FIXME */
+      sprintf(buffer, "anonymous station");
+      /* FIXME: if ident is set, show it? */
+      return buffer;
+   }
    *buffer = '\0';
    sprint_prefix_(ptr);
    return buffer;
