@@ -1,6 +1,6 @@
 /* printwx.cc */
 /* wxWidgets specific parts of Survex wxWidgets printing code */
-/* Copyright (C) 1993-2003,2004,2005,2006,2010,2011,2012,2013 Olly Betts
+/* Copyright (C) 1993-2003,2004,2005,2006,2010,2011,2012,2013,2014 Olly Betts
  * Copyright (C) 2001,2004 Philip Underwood
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,17 +22,6 @@
 # include <config.h>
 #endif
 
-#include <vector>
-
-using namespace std;
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <string.h>
-#include <ctype.h>
-#include <float.h>
-#include <limits.h>
 #include <wx/confbase.h>
 #include <wx/filename.h>
 #include <wx/print.h>
@@ -42,6 +31,16 @@ using namespace std;
 #include <wx/statbox.h>
 #include <wx/valgen.h>
 
+#include <vector>
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <math.h>
+#include <string.h>
+#include <ctype.h>
+#include <float.h>
+#include <limits.h>
+
 #include "debug.h" /* for BUG and SVX_ASSERT */
 #include "export.h"
 #include "filelist.h"
@@ -55,6 +54,8 @@ using namespace std;
 #include "mainfrm.h"
 #include "printwx.h"
 
+using namespace std;
+
 enum {
 	svx_EXPORT = 1200,
 	svx_FORMAT,
@@ -69,7 +70,7 @@ enum {
 	svx_PASSAGES,
 	svx_BORDERS,
 	svx_BLANKS,
-	svx_INFOBOX,
+	svx_LEGEND,
 	svx_SURFACE,
 	svx_PLAN,
 	svx_ELEV,
@@ -277,13 +278,14 @@ static int msg_filetype[] = {
 // there are three jobs to do here...
 // User <-> wx - this should possibly be done in a separate file
 svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
-			 const wxString & title, const wxString & datestamp,
+			 const wxString & title,
+			 const wxString & datestamp, time_t datestamp_numeric,
 			 double angle, double tilt_angle,
 			 bool labels, bool crosses, bool legs, bool surf,
 			 bool tubes, bool ents, bool fixes, bool exports,
 			 bool printing)
 	: wxDialog(mainfrm_, -1, wxString(printing ? wmsg(/*Print*/399) : wmsg(/*Export*/383))),
-	  m_layout(wxGetApp().GetPageSetupDialogData()),
+	  m_layout(printing ? wxGetApp().GetPageSetupDialogData() : NULL),
 	  m_File(filename), mainfrm(mainfrm_)
 {
     m_scale = NULL;
@@ -310,6 +312,7 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 	show_mask |= EXPORTS;
     m_layout.show_mask = show_mask;
     m_layout.datestamp = datestamp;
+    m_layout.datestamp_numeric = datestamp_numeric;
     m_layout.rot = int(angle);
     m_layout.title = title;
     if (mainfrm->IsExtendedElevation()) {
@@ -341,13 +344,15 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
     if (!printing) {
 	wxStaticText* label;
 	label = new wxStaticText(this, -1, wxString(wmsg(/*Export format*/410)));
-	m_format = new wxChoice(this, svx_FORMAT, wxDefaultPosition, wxDefaultSize,
-				sizeof(formats) / sizeof(formats[0]), formats);
+	const size_t n_formats = sizeof(formats) / sizeof(formats[0]);
+	m_format = new wxChoice(this, svx_FORMAT,
+				wxDefaultPosition, wxDefaultSize,
+				n_formats, formats);
 	unsigned current_format = 0;
 	wxConfigBase * cfg = wxConfigBase::Get();
 	wxString s;
 	if (cfg->Read(wxT("export_format"), &s, wxString())) {
-	    for (unsigned i = 0; i != sizeof(formats) / sizeof(wxString); ++i) {
+	    for (unsigned i = 0; i != n_formats; ++i) {
 		if (s == formats[i]) {
 		    current_format = i;
 		    break;
@@ -443,7 +448,7 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 			   wxDefaultPosition, wxDefaultSize, 0,
 			   BitValidator(&m_layout.show_mask, FIXES)),
 	    0, wxALIGN_LEFT|wxALL, 2);
-    v3->Add(new wxCheckBox(this, svx_EXPORTS, wmsg(/*Entrances*/420),
+    v3->Add(new wxCheckBox(this, svx_EXPORTS, wmsg(/*Exported Stations*/420),
 			   wxDefaultPosition, wxDefaultSize, 0,
 			   BitValidator(&m_layout.show_mask, EXPORTS)),
 	    0, wxALIGN_LEFT|wxALL, 2);
@@ -476,7 +481,7 @@ svxPrintDlg::svxPrintDlg(MainFrm* mainfrm_, const wxString & filename,
 		0, wxALIGN_LEFT|wxALL, 2);
 //	m_blanks = new wxCheckBox(this, svx_BLANKS, wmsg(/*Blank Pages*/266));
 //	v3->Add(m_blanks, 0, wxALIGN_LEFT|wxALL, 2);
-	v3->Add(new wxCheckBox(this, svx_INFOBOX, wmsg(/*Info Box*/265),
+	v3->Add(new wxCheckBox(this, svx_LEGEND, wmsg(/*Legend*/265),
 			       wxDefaultPosition, wxDefaultSize, 0,
 			       wxGenericValidator(&m_layout.Legend)),
 		0, wxALIGN_LEFT|wxALL, 2);
@@ -574,7 +579,8 @@ svxPrintDlg::OnExport(wxCommandEvent&) {
 	double text_height = 0.6;
 	double marker_size = 0.8;
 
-	if (!Export(dlg.GetPath(), m_layout.title, mainfrm,
+	if (!Export(dlg.GetPath(), m_layout.title,
+		    m_layout.datestamp, m_layout.datestamp_numeric, mainfrm,
 		    m_layout.rot, m_layout.tilt, m_layout.show_mask,
 		    export_format(format_idx), input_projection.mb_str(),
 		    grid, text_height, marker_size)) {
@@ -672,21 +678,28 @@ svxPrintDlg::SomethingChanged(int control_id) {
 	int new_filter_idx = m_format->GetSelection();
 	if (new_filter_idx != wxNOT_FOUND) {
 	    unsigned mask = format_info[new_filter_idx];
-	    FindWindow(svx_LEGS)->Show(mask & LEGS);
-	    FindWindow(svx_SURFACE)->Show(mask & SURF);
-	    FindWindow(svx_STATIONS)->Show(mask & STNS);
-	    FindWindow(svx_NAMES)->Show(mask & LABELS);
-	    FindWindow(svx_XSECT)->Show(mask & XSECT);
-	    FindWindow(svx_WALLS)->Show(mask & WALLS);
-	    FindWindow(svx_PASSAGES)->Show(mask & PASG);
-	    FindWindow(svx_ENTS)->Show(mask & ENTS);
-	    FindWindow(svx_FIXES)->Show(mask & FIXES);
-	    FindWindow(svx_EXPORTS)->Show(mask & EXPORTS);
-	    FindWindow(svx_CENTRED)->Show(mask & CENTRED);
-	    FindWindow(svx_FULLCOORDS)->Show(mask & FULL_COORDS);
+	    static const struct { int id; unsigned mask; } controls[] = {
+		{ svx_LEGS, LEGS },
+		{ svx_SURFACE, SURF },
+		{ svx_STATIONS, STNS },
+		{ svx_NAMES, LABELS },
+		{ svx_XSECT, XSECT },
+		{ svx_WALLS, WALLS },
+		{ svx_PASSAGES, PASG },
+		{ svx_ENTS, ENTS },
+		{ svx_FIXES, FIXES },
+		{ svx_EXPORTS, EXPORTS },
+		{ svx_CENTRED, CENTRED },
+		{ svx_FULLCOORDS, FULL_COORDS },
 #if 0
-	    FindWindow(svx_PROJ)->Show(mask & PROJ);
+		{ svx_PROJ, PROJ },
 #endif
+	    };
+	    static unsigned n_controls = sizeof(controls) / sizeof(controls[0]);
+	    for (unsigned i = 0; i != n_controls; ++i) {
+		wxWindow * control = FindWindow(controls[i].id);
+		if (control) control->Show(mask & controls[i].mask);
+	    }
 	    m_scalebox->Show(bool(mask & SCALE));
 	    m_viewbox->Show(!bool(mask & EXPORT_3D));
 	    GetSizer()->Layout();
@@ -740,7 +753,7 @@ void
 svxPrintDlg::UIToLayout(){
 //    m_layout.SkipBlank = m_blanks->IsChecked();
 
-    if (m_layout.view != layout::EXTELEV) {
+    if (m_layout.view != layout::EXTELEV && m_tilt) {
 	m_layout.tilt = m_tilt->GetValue();
 	if (m_layout.tilt == -90) {
 	    m_layout.view = layout::PLAN;
@@ -987,15 +1000,7 @@ svxPrintout::draw_scale_bar(double x, double y, double MaxLength)
 {
    double StepEst, d;
    int E, Step, n, c;
-   char u_buf[3];
    wxString buf;
-   static const signed char powers[] = {
-      12, 9, 9, 9, 6, 6, 6, 3, 2, 2, 0, 0, 0, -3, -3, -3, -6, -6, -6, -9,
-   };
-   static const char si_mods[sizeof(powers)] = {
-      'p', 'n', 'n', 'n', 'u', 'u', 'u', 'm', 'c', 'c', '\0', '\0', '\0',
-      'k', 'k', 'k', 'M', 'M', 'M', 'G'
-   };
    /* Limit scalebar to 20cm to stop people with A0 plotters complaining */
    if (MaxLength > 200.0) MaxLength = 200.0;
 
@@ -1012,20 +1017,29 @@ svxPrintout::draw_scale_bar(double x, double y, double MaxLength)
    /* Work out actual length of each scale bar division */
    d = Step * pow(10.0, (double)E) / m_layout->Scale * 1000.0;
 
+   /* FIXME: Non-metric units here... */
    /* Choose appropriate units, s.t. if possible E is >=0 and minimized */
-   /* Range of units is a little extreme, but it doesn't hurt... */
-   n = min(E, 9);
-   n = max(n, -10) + 10;
-   E += (int)powers[n];
-
-   u_buf[0] = si_mods[n];
-   u_buf[1] = '\0';
-   strcat(u_buf, "m");
+   int units;
+   if (E >= 3) {
+      E -= 3;
+      units = /*km*/423;
+   } else if (E >= 0) {
+      units = /*m*/424;
+   } else {
+      E += 2;
+      units = /*cm*/425;
+   }
 
    buf = wmsg(/*Scale*/154);
 
    /* Add units used - eg. "Scale (10m)" */
-   buf.Append(wxString::Format(wxT(" (%.0f%s)"), (double)pow(10.0, (double)E), wxString::FromAscii(u_buf).c_str()));
+   double pow10_E = pow(10.0, (double)E);
+   if (E >= 0) {
+      buf += wxString::Format(wxT(" (%.f%s)"), pow10_E, wmsg(units).c_str());
+   } else {
+      int sf = -(int)floor(E);
+      buf += wxString::Format(wxT(" (%.*f%s)"), sf, pow10_E, wmsg(units).c_str());
+   }
    SetColour(PR_COLOUR_TEXT);
    MOVEMM(x, y + 4); WriteString(buf);
 
@@ -1880,7 +1894,7 @@ svxPrintout::Init(FILE **fh_list, bool fCalibrate)
    };
    char **vals;
 
-   fCalibrate = fCalibrate; /* suppress unused argument warning */
+   (void)fCalibrate; /* suppress unused argument warning */
 
    vals = ini_read(fh_list, "aven", vars);
    fontsize_labels = 10;
