@@ -1,6 +1,6 @@
 /* readval.c
  * Routines to read a prefix or number from the current input file
- * Copyright (C) 1991-2003,2005,2006,2010,2011 Olly Betts
+ * Copyright (C) 1991-2003,2005,2006,2010,2011,2012,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,10 +43,38 @@
 
 int root_depr_count = 0;
 
-/* if prefix is omitted: if f_optional return NULL, otherwise use longjmp */
 static prefix *
-read_prefix_(bool f_optional, bool fSurvey, bool fSuspectTypo, bool fAllowRoot)
+new_anon_station(void)
 {
+    prefix *name = osnew(prefix);
+    name->pos = NULL;
+    name->ident = NULL;
+    name->shape = 0;
+    name->stn = NULL;
+    name->up = pcs->Prefix;
+    name->down = NULL;
+    name->filename = file.filename;
+    name->line = file.line;
+    if (TSTBIT(pcs->infer, INFER_EXPORTS)) {
+	name->min_export = USHRT_MAX;
+    } else {
+	name->min_export = 0;
+    }
+    name->max_export = 0;
+    name->sflags = BIT(SFLAGS_ANON);
+    /* Keep linked list of anon stations for node stats. */
+    name->right = anon_list;
+    anon_list = name;
+    return name;
+}
+
+/* if prefix is omitted: if PFX_OPT set return NULL, otherwise use longjmp */
+extern prefix *
+read_prefix(unsigned pfx_flags)
+{
+   bool f_optional = !!(pfx_flags & PFX_OPT);
+   bool fSurvey = !!(pfx_flags & PFX_SURVEY);
+   bool fSuspectTypo = !!(pfx_flags & PFX_SUSPECT_TYPO);
    prefix *back_ptr, *ptr;
    char *name;
    size_t name_len = 32;
@@ -58,12 +86,12 @@ read_prefix_(bool f_optional, bool fSurvey, bool fSuspectTypo, bool fAllowRoot)
    skipblanks();
 #ifndef NO_DEPRECATED
    if (isRoot(ch)) {
-      if (!fAllowRoot) {
-	 compile_error_skip(/*ROOT is deprecated*/25);
+      if (!(pfx_flags & PFX_ALLOW_ROOT)) {
+	 compile_error(-/*ROOT is deprecated*/25);
 	 LONGJMP(file.jbSkipLine);
       }
       if (root_depr_count < 5) {
-	 compile_warning(/*ROOT is deprecated*/25);
+	 compile_warning(-/*ROOT is deprecated*/25);
 	 if (++root_depr_count == 5)
 	    compile_warning(/*Further uses of this deprecated feature will not be reported*/95);
       }
@@ -75,18 +103,73 @@ read_prefix_(bool f_optional, bool fSurvey, bool fSuspectTypo, bool fAllowRoot)
 	 nextch();
       }
       fImplicitPrefix = fFalse;
+#else
+   if (0) {
+#endif
    } else {
+      if ((pfx_flags & PFX_ANON) &&
+	  (isSep(ch) || (pcs->dash_for_anon_wall_station && ch == '-'))) {
+	 int first_ch = ch;
+	 filepos here;
+	 get_pos(&here);
+	 nextch();
+	 if (isBlank(ch) || isEol(ch)) {
+	    if (!isSep(first_ch))
+	       goto anon_wall_station;
+	    /* A single separator alone ('.' by default) is an anonymous
+	     * station which is on a point inside the passage and implies
+	     * the leg to it is a splay.
+	     */
+	    if (TSTBIT(pcs->flags, FLAGS_ANON_ONE_END)) {
+	       compile_error(-/*Can't have a leg between two anonymous stations*/3);
+	       LONGJMP(file.jbSkipLine);
+	    }
+	    pcs->flags |= BIT(FLAGS_ANON_ONE_END) | BIT(FLAGS_IMPLICIT_SPLAY);
+	    return new_anon_station();
+	 }
+	 if (isSep(first_ch) && ch == first_ch) {
+	    nextch();
+	    if (isBlank(ch) || isEol(ch)) {
+	       /* A double separator ('..' by default) is an anonymous station
+		* which is on the wall and implies the leg to it is a splay.
+		*/
+	       prefix * pfx;
+anon_wall_station:
+	       if (TSTBIT(pcs->flags, FLAGS_ANON_ONE_END)) {
+		  compile_error(-/*Can't have a leg between two anonymous stations*/3);
+		  LONGJMP(file.jbSkipLine);
+	       }
+	       pcs->flags |= BIT(FLAGS_ANON_ONE_END) | BIT(FLAGS_IMPLICIT_SPLAY);
+	       pfx = new_anon_station();
+	       pfx->sflags |= BIT(SFLAGS_WALL);
+	       return pfx;
+	    }
+	    if (ch == first_ch) {
+	       nextch();
+	       if (isBlank(ch) || isEol(ch)) {
+		  /* A triple separator ('...' by default) is an anonymous
+		   * station, but otherwise not handled specially (e.g. for
+		   * a single leg down an unexplored side passage to a station
+		   * which isn't refindable).
+		   */
+		  if (TSTBIT(pcs->flags, FLAGS_ANON_ONE_END)) {
+		     compile_error(-/*Can't have a leg between two anonymous stations*/3);
+		     LONGJMP(file.jbSkipLine);
+		  }
+		  pcs->flags |= BIT(FLAGS_ANON_ONE_END);
+		  return new_anon_station();
+	       }
+	    }
+	 }
+	 set_pos(&here);
+      }
       ptr = pcs->Prefix;
    }
-#else
-   ptr = pcs->Prefix;
-#endif
 
    i = 0;
    name = NULL;
    do {
       fNew = fFalse;
-      if (isSep(ch)) fImplicitPrefix = fFalse;
       if (name == NULL) {
 	 /* Need a new name buffer */
 	 name = osmalloc(name_len);
@@ -108,17 +191,18 @@ read_prefix_(bool f_optional, bool fSurvey, bool fSuspectTypo, bool fAllowRoot)
 	 }
 	 nextch();
       }
+      if (isSep(ch)) fImplicitPrefix = fFalse;
       if (i == 0) {
 	 osfree(name);
 	 if (!f_optional) {
 	    if (isEol(ch)) {
 	       if (fSurvey) {
-		  compile_error_skip(/*Expecting survey name*/89);
+		  compile_error(-/*Expecting survey name*/89);
 	       } else {
-		  compile_error_skip(/*Expecting station name*/28);
+		  compile_error(-/*Expecting station name*/28);
 	       }
 	    } else {
-	       compile_error_skip(/*Character “%c” not allowed in station name (use *SET NAMES to set allowed characters)*/7, ch);
+	       compile_error(-/*Character “%c” not allowed in station name (use *SET NAMES to set allowed characters)*/7, ch);
 	    }
 	    LONGJMP(file.jbSkipLine);
 	 }
@@ -250,31 +334,12 @@ read_prefix_(bool f_optional, bool fSurvey, bool fSuspectTypo, bool fAllowRoot)
 	     depth, ptr->max_export);
 #endif
    }
+   if (!fImplicitPrefix && (pfx_flags & PFX_WARN_SEPARATOR)) {
+      compile_warning(/*Separator in survey name*/392);
+   }
    return ptr;
 }
 
-/* if prefix is omitted: if f_optional return NULL, otherwise use longjmp */
-extern prefix *
-read_prefix_survey(bool f_optional, bool fAllowRoot)
-{
-   return read_prefix_(f_optional, fTrue, fFalse, fAllowRoot);
-}
-
-/* if prefix is omitted: if f_optional return NULL, otherwise use longjmp */
-extern prefix *
-read_prefix_stn(bool f_optional, bool fAllowRoot)
-{
-   return read_prefix_(f_optional, fFalse, fFalse, fAllowRoot);
-}
-
-/* if prefix is omitted: if f_optional return NULL, otherwise use longjmp */
-/* Same as read_prefix_stn but implicit checks are made */
-extern prefix *
-read_prefix_stn_check_implicit(bool f_optional, bool fAllowRoot)
-{
-   return read_prefix_(f_optional, fFalse, fTrue, fAllowRoot);
-}
-
 /* if numeric expr is omitted: if f_optional return HUGE_REAL, else longjmp */
 static real
 read_number(bool f_optional)
@@ -310,15 +375,15 @@ read_number(bool f_optional)
    if (fDigits) return (fPositive ? n : -n);
 
    /* didn't read a valid number.  If it's optional, reset filepos & return */
+   set_pos(&fp);
    if (f_optional) {
-      set_pos(&fp);
       return HUGE_REAL;
    }
 
    if (isOmit(ch_old)) {
-      compile_error(/*Field may not be omitted*/8);
+      compile_error(-/*Field may not be omitted*/8);
    } else {
-      compile_error_token(/*Expecting numeric field, found “%s”*/9);
+      compile_error_token(-/*Expecting numeric field, found “%s”*/9);
    }
    LONGJMP(file.jbSkipLine);
    return 0.0; /* for brain-fried compilers */
@@ -359,7 +424,7 @@ read_numeric_or_omit(int *p_n_readings)
    real v = read_numeric(fTrue, p_n_readings);
    if (v == HUGE_REAL) {
       if (!isOmit(ch)) {
-	 compile_error_token(/*Expecting numeric field, found “%s”*/9);
+	 compile_error_token(-/*Expecting numeric field, found “%s”*/9);
 	 LONGJMP(file.jbSkipLine);
 	 return 0.0; /* for brain-fried compilers */
       }
@@ -370,12 +435,12 @@ read_numeric_or_omit(int *p_n_readings)
 
 /* Don't skip blanks, variable error code */
 static unsigned int
-read_uint_internal(int errmsg, filepos *fp)
+read_uint_internal(int errmsg, const filepos *fp)
 {
    unsigned int n = 0;
    if (!isdigit(ch)) {
       if (fp) set_pos(fp);
-      compile_error_token(errmsg);
+      compile_error_token(-errmsg);
       LONGJMP(file.jbSkipLine);
    }
    while (isdigit(ch)) {
@@ -403,8 +468,8 @@ read_string(char **pstr, int *plen)
       nextch();
       while (1) {
 	 if (isEol(ch)) {
-	    compile_error_skip(/*Missing \"*/69);
-	    return;
+	    compile_error(-/*Missing \"*/69);
+	    LONGJMP(file.jbSkipLine);
 	 }
 
 	 if (ch == '\"') break;
@@ -417,7 +482,8 @@ read_string(char **pstr, int *plen)
       while (1) {
 	 if (isEol(ch) || isComm(ch)) {
 	    if (!*pstr || !(*pstr)[0]) {
-	       compile_error_skip(/*Expecting string field*/121);
+	       compile_error(-/*Expecting string field*/121);
+	       LONGJMP(file.jbSkipLine);
 	    }
 	    return;
 	 }
@@ -445,7 +511,7 @@ read_date(int *py, int *pm, int *pd)
    /* Two digit year is 19xx. */
    if (y < 100) y += 1900;
    if (y < 1900 || y > 2078) {
-      compile_error_skip(/*Invalid year (< 1900 or > 2078)*/58);
+      compile_warning(/*Invalid year (< 1900 or > 2078)*/58);
       LONGJMP(file.jbSkipLine);
       return; /* for brain-fried compilers */
    }
@@ -453,7 +519,7 @@ read_date(int *py, int *pm, int *pd)
       nextch();
       m = read_uint_internal(/*Expecting date, found “%s”*/198, &fp);
       if (m < 1 || m > 12) {
-	 compile_error_skip(/*Invalid month*/86);
+	 compile_warning(/*Invalid month*/86);
 	 LONGJMP(file.jbSkipLine);
 	 return; /* for brain-fried compilers */
       }
@@ -461,7 +527,7 @@ read_date(int *py, int *pm, int *pd)
 	 nextch();
 	 d = read_uint_internal(/*Expecting date, found “%s”*/198, &fp);
 	 if (d < 1 || d > last_day(y, m)) {
-	    compile_error_skip(/*Invalid day of the month*/87);
+	    compile_warning(/*Invalid day of the month*/87);
 	    LONGJMP(file.jbSkipLine);
 	    return; /* for brain-fried compilers */
 	 }
