@@ -692,7 +692,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 	      char *buf;
 
-	      if (__asprintf (&buf, msg(/*%s: option `%s' is ambiguous\n*/300),
+	      if (__asprintf (&buf, msg(/*%s: option “%s” is ambiguous\n*/300),
 			      argv[0], argv[optind]) >= 0)
 		{
 
@@ -704,7 +704,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		  free (buf);
 		}
 #else
-	      fprintf (stderr, msg(/*%s: option `%s' is ambiguous\n*/300),
+	      fprintf (stderr, msg(/*%s: option “%s” is ambiguous\n*/300),
 		       argv[0], argv[optind]);
 #endif
 	    }
@@ -737,10 +737,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			{
 			  /* --option */
 #if defined _LIBC && defined USE_IN_LIBIO
-			  n = __asprintf (&buf, msg(/*%s: option `--%s' doesn't allow an argument\n*/303),
+			  n = __asprintf (&buf, msg(/*%s: option “--%s” doesn’t allow an argument\n*/303),
 					  argv[0], pfound->name);
 #else
-			  fprintf (stderr, msg(/*%s: option `--%s' doesn't allow an argument\n*/303),
+			  fprintf (stderr, msg(/*%s: option “--%s” doesn’t allow an argument\n*/303),
 				   argv[0], pfound->name);
 #endif
 			}
@@ -748,11 +748,11 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			{
 			  /* +option or -option */
 #if defined _LIBC && defined USE_IN_LIBIO
-			  n = __asprintf (&buf, msg(/*%s: option `%c%s' doesn't allow an argument\n*/302),
+			  n = __asprintf (&buf, msg(/*%s: option “%c%s” doesn’t allow an argument\n*/302),
 					  argv[0], argv[optind - 1][0],
 					  pfound->name);
 #else
-			  fprintf (stderr, msg(/*%s: option `%c%s' doesn't allow an argument\n*/302),
+			  fprintf (stderr, msg(/*%s: option “%c%s” doesn’t allow an argument\n*/302),
 				   argv[0], argv[optind - 1][0], pfound->name);
 #endif
 			}
@@ -787,7 +787,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		      char *buf;
 
-		      if (__asprintf (&buf, msg(/*%s: option `%s' requires an argument\n*/305),
+		      if (__asprintf (&buf, msg(/*%s: option “%s” requires an argument\n*/305),
 				      argv[0], argv[optind - 1]) >= 0)
 			{
 			  if (_IO_fwide (stderr, 0) > 0)
@@ -799,7 +799,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			}
 #else
 		      fprintf (stderr,
-			       msg(/*%s: option `%s' requires an argument\n*/305),
+			       msg(/*%s: option “%s” requires an argument\n*/305),
 			       argv[0], argv[optind - 1]);
 #endif
 		    }
@@ -837,10 +837,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		{
 		  /* --option */
 #if defined _LIBC && defined USE_IN_LIBIO
-		  n = __asprintf (&buf, msg(/*%s: unrecognized option `--%s'\n*/307),
+		  n = __asprintf (&buf, msg(/*%s: unrecognized option “--%s”\n*/307),
 				  argv[0], nextchar);
 #else
-		  fprintf (stderr, msg(/*%s: unrecognized option `--%s'\n*/307),
+		  fprintf (stderr, msg(/*%s: unrecognized option “--%s”\n*/307),
 			   argv[0], nextchar);
 #endif
 		}
@@ -848,10 +848,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		{
 		  /* +option or -option */
 #if defined _LIBC && defined USE_IN_LIBIO
-		  n = __asprintf (&buf, msg(/*%s: unrecognized option `%c%s'\n*/308),
+		  n = __asprintf (&buf, msg(/*%s: unrecognized option “%c%s”\n*/308),
 				  argv[0], argv[optind][0], nextchar);
 #else
-		  fprintf (stderr, msg(/*%s: unrecognized option `%c%s'\n*/308),
+		  fprintf (stderr, msg(/*%s: unrecognized option “%c%s”\n*/308),
 			   argv[0], argv[optind][0], nextchar);
 #endif
 		}
@@ -1020,7 +1020,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		char *buf;
 
-		if (__asprintf (&buf, msg(/*%s: option `-W %s' is ambiguous\n*/301),
+		if (__asprintf (&buf, msg(/*%s: option “-W %s” is ambiguous\n*/301),
 				argv[0], argv[optind]) >= 0)
 		  {
 		    if (_IO_fwide (stderr, 0) > 0)
@@ -1031,7 +1031,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		    free (buf);
 		  }
 #else
-		fprintf (stderr, msg(/*%s: option `-W %s' is ambiguous\n*/301),
+		fprintf (stderr, msg(/*%s: option “-W %s” is ambiguous\n*/301),
 			 argv[0], argv[optind]);
 #endif
 	      }
@@ -1055,7 +1055,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 			char *buf;
 
-			if (__asprintf (&buf, msg(/*%s: option `-W %s' doesn't allow an argument\n*/304),
+			if (__asprintf (&buf, msg(/*%s: option “-W %s” doesn’t allow an argument\n*/304),
 					argv[0], pfound->name) >= 0)
 			  {
 			    if (_IO_fwide (stderr, 0) > 0)
@@ -1066,7 +1066,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			    free (buf);
 			  }
 #else
-			fprintf (stderr, msg(/*%s: option `-W %s' doesn't allow an argument\n*/304),
+			fprintf (stderr, msg(/*%s: option “-W %s” doesn’t allow an argument\n*/304),
 				 argv[0], pfound->name);
 #endif
 		      }
@@ -1086,7 +1086,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 			char *buf;
 
-			if (__asprintf (&buf, msg(/*%s: option `%s' requires an argument\n*/305),
+			if (__asprintf (&buf, msg(/*%s: option “%s” requires an argument\n*/305),
 					argv[0], argv[optind - 1]) >= 0)
 			  {
 			    if (_IO_fwide (stderr, 0) > 0)
@@ -1098,7 +1098,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			  }
 #else
 			fprintf (stderr,
-				 msg(/*%s: option `%s' requires an argument\n*/305),
+				 msg(/*%s: option “%s” requires an argument\n*/305),
 				 argv[0], argv[optind - 1]);
 #endif
 		      }
